@@ -70,9 +70,6 @@ function configure_mistral {
     oslo-config-generator --config-file $MISTRAL_DIR/tools/config/config-generator.mistral.conf --output-file $MISTRAL_CONF_FILE
     iniset $MISTRAL_CONF_FILE DEFAULT debug $MISTRAL_DEBUG
 
-    MISTRAL_POLICY_FILE=$MISTRAL_CONF_DIR/policy.json
-    cp $MISTRAL_DIR/etc/policy.json $MISTRAL_POLICY_FILE
-
     # Run all Mistral processes as a single process
     iniset $MISTRAL_CONF_FILE DEFAULT server all
 
@@ -94,9 +91,6 @@ function configure_mistral {
     # Configure action execution deletion policy
     iniset $MISTRAL_CONF_FILE api allow_action_execution_deletion True
 
-    # Path of policy.json file.
-    iniset $MISTRAL_CONF oslo_policy policy_file $MISTRAL_POLICY_FILE
-
     if [ "$LOG_COLOR" == "True" ] && [ "$SYSLOG" == "False" ]; then
         setup_colorized_logging $MISTRAL_CONF_FILE DEFAULT tenant user
     fi
@@ -115,7 +109,7 @@ function configure_mistral {
 function init_mistral {
     # (re)create Mistral database
     recreate_database mistral utf8
-    python $MISTRAL_DIR/tools/sync_db.py --config-file $MISTRAL_CONF_FILE
+    $PYTHON $MISTRAL_DIR/tools/sync_db.py --config-file $MISTRAL_CONF_FILE
 }
 
 
@@ -155,7 +149,7 @@ function install_mistral_pythonclient {
 }
 
 
-# start_mistral - Start running processes, including screen
+# start_mistral - Start running processes
 function start_mistral {
     # If the site is not enabled then we are in a grenade scenario
     local enabled_site_file
@@ -166,7 +160,6 @@ function start_mistral {
         if [ -f ${enabled_site_file} ] && [ "$MISTRAL_USE_MOD_WSGI" == "True" ]; then
             enable_apache_site mistral-api
             restart_apache_server
-            tail_log mistral-api /var/log/$APACHE_NAME/mistral_api.log
         else
             run_process mistral-api "$MISTRAL_BIN_DIR/mistral-server --server api --config-file $MISTRAL_CONF_DIR/mistral.conf"
         fi
@@ -182,7 +175,6 @@ function start_mistral {
 
 # stop_mistral - Stop running processes
 function stop_mistral {
-    # Kill the Mistral screen windows
     local serv
     for serv in mistral mistral-engine mistral-executor mistral-event-engine; do
         stop_process $serv
