@@ -15,7 +15,7 @@
 # How many seconds to wait for the API to be responding before giving up
 API_RESPONDING_TIMEOUT=20
 
-if ! timeout ${API_RESPONDING_TIMEOUT} sh -c "while ! curl -s http://127.0.0.1:8989/v1/ 2>/dev/null | grep -q 'Authentication required' ; do sleep 1; done"; then
+if ! timeout ${API_RESPONDING_TIMEOUT} sh -c "until curl --output /dev/null --silent --head --fail http://localhost:8989; do sleep 1; done"; then
     echo "Mistral API failed to respond within ${API_RESPONDING_TIMEOUT} seconds"
     exit 1
 fi
@@ -23,9 +23,19 @@ fi
 echo "Successfully contacted Mistral API"
 
 # Where tempest code lives
-TEMPEST_DIR=${TEMPEST_DIR:-/opt/stack/new/tempest}
+TEMPEST_DIR=${TEMPEST_DIR:-/opt/stack/tempest}
 
-# Add tempest source tree to PYTHONPATH
+# Path to directory with tempest.conf file, otherwise it will
+# take relative path from where the run tests command is being executed.
+export TEMPEST_CONFIG_DIR=${TEMPEST_CONFIG_DIR:-$TEMPEST_DIR/etc/}
+echo "Tempest configuration file directory: $TEMPEST_CONFIG_DIR"
+
+# Where mistral code and mistralclient code live
+MISTRAL_DIR=/opt/stack/mistral
+MISTRALCLIENT_DIR=/opt/stack/python-mistralclient
+
+# Define PYTHONPATH
 export PYTHONPATH=$PYTHONPATH:$TEMPEST_DIR
 
-nosetests -sv api/v1
+pwd
+nosetests -sv mistral_tempest_tests/tests/
