@@ -12,14 +12,17 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from mistral.openstack.common import importutils
+from oslo_utils import importutils
 
 
 def construct_action_class(action_class_str, attributes):
     # Rebuild action class and restore attributes.
     action_class = importutils.import_class(action_class_str)
 
-    for name, value in attributes.items():
-        setattr(action_class, name, value)
+    unique_action_class = type(
+        action_class.__name__,
+        (action_class,),
+        attributes
+    )
 
-    return action_class
+    return unique_action_class
