@@ -23,12 +23,8 @@ from mistral.actions import action_generator
 from mistral.utils import inspect_utils as i_u
 from mistral import version
 
-os_actions_mapping_path = cfg.StrOpt('openstack_actions_mapping_path',
-                                     default='actions/openstack/mapping.json')
-
-
 CONF = cfg.CONF
-CONF.register_opt(os_actions_mapping_path)
+
 LOG = logging.getLogger(__name__)
 
 
@@ -47,8 +43,10 @@ def get_mapping():
         path = CONF.openstack_actions_mapping_path
         mapping_file_path = pkg.resource_filename(package, path)
 
-    LOG.info("Processing OpenStack action mapping from file: %s",
-             mapping_file_path)
+    LOG.info(
+        "Processing OpenStack action mapping from file: %s",
+        mapping_file_path
+    )
 
     with open(mapping_file_path) as fh:
         mapping = json.load(fh)
@@ -71,6 +69,56 @@ class OpenStackActionGenerator(action_generator.ActionGenerator):
     action_namespace = None
     base_action_class = None
 
+    @classmethod
+    def prepare_action_inputs(cls, origin_inputs, added=[]):
+        """Modify action input string.
+
+        Sometimes we need to change the default action input definition for
+        OpenStack actions in order to make the workflow more powerful.
+
+        Examples::
+
+            >>> prepare_action_inputs('a,b,c', added=['region=RegionOne'])
+            a, b, c, region=RegionOne
+            >>> prepare_action_inputs('a,b,c=1', added=['region=RegionOne'])
+            a, b, region=RegionOne, c=1
+            >>> prepare_action_inputs('a,b,c=1,**kwargs',
+                                      added=['region=RegionOne'])
+            a, b, region=RegionOne, c=1, **kwargs
+            >>> prepare_action_inputs('**kwargs', added=['region=RegionOne'])
+            region=RegionOne, **kwargs
+            >>> prepare_action_inputs('', added=['region=RegionOne'])
+            region=RegionOne
+
+        :param origin_inputs: A string consists of action inputs, separated by
+            comma.
+        :param added: (Optional) A list of params to add to input string.
+        :return: The new action input string.
+        """
+        if not origin_inputs:
+            return ", ".join(added)
+
+        inputs = [i.strip() for i in origin_inputs.split(',')]
+        kwarg_index = None
+
+        for index, input in enumerate(inputs):
+            if "=" in input:
+                kwarg_index = index
+            if "**" in input:
+                kwarg_index = index - 1
+
+        kwarg_index = len(inputs) if kwarg_index is None else kwarg_index
+        kwarg_index = kwarg_index + 1 if kwarg_index < 0 else kwarg_index
+
+        for a in added:
+            if "=" not in a:
+                inputs.insert(0, a)
+                kwarg_index += 1
+            else:
+                inputs.insert(kwarg_index, a)
+
+        return ", ".join(inputs)
+
     @classmethod
     def create_action_class(cls, method_name):
         if not method_name:
@@ -84,30 +132,37 @@ class OpenStackActionGenerator(action_generator.ActionGenerator):
     @classmethod
     def create_actions(cls):
         mapping = get_mapping()
-        method_dict = mapping[cls.action_namespace]
+        method_dict = mapping.get(cls.action_namespace, {})
 
         action_classes = []
 
         for action_name, method_name in method_dict.items():
-            clazz = cls.create_action_class(method_name)
+            class_ = cls.create_action_class(method_name)
 
             try:
-                client_method = clazz.get_fake_client_method()
-            except Exception as e:
-                LOG.warning("Failed to create action: %s.%s %s" %
-                            (cls.action_namespace, action_name, e))
-                client_method = None
+                client_method = class_.get_fake_client_method()
+            except Exception:
+                LOG.exception(
+                    "Failed to create action: %s.%s",
+                    cls.action_namespace, action_name
+                )
+                continue
 
-            if client_method:
-                arg_list = i_u.get_arg_list_as_str(client_method)
-                description = i_u.get_docstring(client_method)
-            else:
-                arg_list = ''
-                description = None
+            arg_list = i_u.get_arg_list_as_str(client_method)
+
+            # Support specifying region for OpenStack actions.
+            modules = CONF.openstack_actions.modules_support_region
+            if cls.action_namespace in modules:
+                arg_list = cls.prepare_action_inputs(
+                    arg_list,
+                    added=['action_region=""']
+                )
+
+            description = i_u.get_docstring(client_method)
 
             action_classes.append(
                 {
-                    'class': clazz,
+                    'class': class_,
                     'name': "%s.%s" % (cls.action_namespace, action_name),
                     'description': description,
                     'arg_list': arg_list,
