@@ -69,7 +69,6 @@ def _get_action_execution_resource(action_ex):
 
 
 def _get_action_execution_resource_for_list(action_ex):
-
     # TODO(nmakhotkin): Get rid of using dicts for constructing resources.
     # TODO(nmakhotkin): Use db_model for this instead.
     res = resources.ActionExecution.from_db_model(action_ex)
@@ -138,7 +137,7 @@ class ActionExecutionsController(rest.RestController):
         """
         acl.enforce('action_executions:get', context.ctx())
 
-        LOG.info("Fetch action_execution [id=%s]", id)
+        LOG.debug("Fetch action_execution [id=%s]", id)
 
         return _get_action_execution(id)
 
@@ -152,7 +151,7 @@ class ActionExecutionsController(rest.RestController):
         """
         acl.enforce('action_executions:create', context.ctx())
 
-        LOG.info(
+        LOG.debug(
             "Create action_execution [action_execution=%s]",
             action_ex
         )
@@ -190,7 +189,7 @@ class ActionExecutionsController(rest.RestController):
         """
         acl.enforce('action_executions:update', context.ctx())
 
-        LOG.info(
+        LOG.debug(
             "Update action_execution [id=%s, action_execution=%s]",
             id,
             action_ex
@@ -300,7 +299,7 @@ class ActionExecutionsController(rest.RestController):
             description=description
         )
 
-        LOG.info(
+        LOG.debug(
             "Fetch action_executions. marker=%s, limit=%s, "
             "sort_keys=%s, sort_dirs=%s, filters=%s",
             marker,
@@ -329,7 +328,7 @@ class ActionExecutionsController(rest.RestController):
         """
         acl.enforce('action_executions:delete', context.ctx())
 
-        LOG.info("Delete action_execution [id=%s]", id)
+        LOG.debug("Delete action_execution [id=%s]", id)
 
         if not cfg.CONF.api.allow_action_execution_deletion:
             raise exc.NotAllowedException("Action execution deletion is not "
@@ -429,7 +428,7 @@ class TasksActionExecutionController(rest.RestController):
             description=description
         )
 
-        LOG.info(
+        LOG.debug(
             "Fetch action_executions. marker=%s, limit=%s, "
             "sort_keys=%s, sort_dirs=%s, filters=%s",
             marker,
@@ -459,6 +458,6 @@ class TasksActionExecutionController(rest.RestController):
         """
         acl.enforce('action_executions:get', context.ctx())
 
-        LOG.info("Fetch action_execution [id=%s]", action_ex_id)
+        LOG.debug("Fetch action_execution [id=%s]", action_ex_id)
 
         return _get_action_execution(action_ex_id)
