@@ -32,18 +32,18 @@ LOG = logging.getLogger(__name__)
 class CronTriggersController(rest.RestController):
     @rest_utils.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(resources.CronTrigger, wtypes.text)
-    def get(self, name):
+    def get(self, identifier):
         """Returns the named cron_trigger.
 
-        :param name: Name of cron trigger to retrieve
+        :param identifier: Id or name of cron trigger to retrieve
         """
         acl.enforce('cron_triggers:get', context.ctx())
 
-        LOG.info('Fetch cron trigger [name=%s]', name)
+        LOG.debug('Fetch cron trigger [identifier=%s]', identifier)
 
         # Use retries to prevent possible failures.
         r = rest_utils.create_db_retry_object()
-        db_model = r.call(db_api.get_cron_trigger, name)
+        db_model = r.call(db_api.get_cron_trigger, identifier)
 
         return resources.CronTrigger.from_db_model(db_model)
 
@@ -60,7 +60,7 @@ class CronTriggersController(rest.RestController):
         """
         acl.enforce('cron_triggers:create', context.ctx())
 
-        LOG.info('Create cron trigger: %s', cron_trigger)
+        LOG.debug('Create cron trigger: %s', cron_trigger)
 
         values = cron_trigger.to_dict()
 
@@ -79,16 +79,16 @@ class CronTriggersController(rest.RestController):
 
     @rest_utils.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
-    def delete(self, name):
+    def delete(self, identifier):
         """Delete cron trigger.
 
-        :param name: Name of cron trigger to delete
+        :param identifier: Id or name of cron trigger to delete
         """
         acl.enforce('cron_triggers:delete', context.ctx())
 
-        LOG.info("Delete cron trigger [name=%s]", name)
+        LOG.debug("Delete cron trigger [identifier=%s]", identifier)
 
-        triggers.delete_cron_trigger(name)
+        triggers.delete_cron_trigger(identifier)
 
     @rest_utils.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(resources.CronTriggers, types.uuid, int,
@@ -96,13 +96,15 @@ class CronTriggersController(rest.RestController):
                          wtypes.text, wtypes.text, types.uuid, types.jsontype,
                          types.jsontype, resources.SCOPE_TYPES, wtypes.text,
                          wtypes.IntegerType(minimum=1), wtypes.text,
-                         wtypes.text, wtypes.text, wtypes.text, bool)
+                         wtypes.text, wtypes.text, wtypes.text,
+                         types.uuid, bool)
     def get_all(self, marker=None, limit=None, sort_keys='created_at',
                 sort_dirs='asc', fields='', name=None, workflow_name=None,
                 workflow_id=None, workflow_input=None, workflow_params=None,
                 scope=None, pattern=None, remaining_executions=None,
                 first_execution_time=None, next_execution_time=None,
-                created_at=None, updated_at=None, all_projects=False):
+                created_at=None, updated_at=None, project_id=None,
+                all_projects=False):
         """Return all cron triggers.
 
         :param marker: Optional. Pagination marker for large data sets.
@@ -132,6 +134,8 @@ class CronTriggersController(rest.RestController):
         :param pattern: Optional. Keep only resources with a specific pattern.
         :param remaining_executions: Optional. Keep only resources with a
                                      specific number of remaining executions.
+        :param project_id: Optional. Keep only resources with the specific
+                           project id.
         :param first_execution_time: Optional. Keep only resources with a
                                      specific time and date of first execution.
         :param next_execution_time: Optional. Keep only resources with a
@@ -159,10 +163,11 @@ class CronTriggersController(rest.RestController):
             pattern=pattern,
             remaining_executions=remaining_executions,
             first_execution_time=first_execution_time,
-            next_execution_time=next_execution_time
+            next_execution_time=next_execution_time,
+            project_id=project_id,
         )
 
-        LOG.info(
+        LOG.debug(
             "Fetch cron triggers. marker=%s, limit=%s, sort_keys=%s, "
             "sort_dirs=%s, filters=%s, all_projects=%s",
             marker, limit, sort_keys, sort_dirs, filters, all_projects
