@@ -33,6 +33,7 @@ class Workbook(resource.Resource):
     tags = [wtypes.text]
     scope = SCOPE_TYPES
     "'private' or 'public'"
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
 
     created_at = wtypes.text
     updated_at = wtypes.text
@@ -45,6 +46,7 @@ class Workbook(resource.Resource):
                         'WORKBOOK DEFINITION IN MISTRAL DSL v2',
                    tags=['large', 'expensive'],
                    scope='private',
+                   project_id='a7eb669e9819420ea4bd1453e672c0a7',
                    created_at='1970-01-01T00:00:00.000000',
                    updated_at='1970-01-01T00:00:00.000000')
 
@@ -167,6 +169,7 @@ class Action(resource.Resource):
     tags = [wtypes.text]
     definition = wtypes.text
     scope = SCOPE_TYPES
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
 
     created_at = wtypes.text
     updated_at = wtypes.text
@@ -179,6 +182,7 @@ class Action(resource.Resource):
             definition='HERE GOES ACTION DEFINITION IN MISTRAL DSL v2',
             tags=['large', 'expensive'],
             scope='private',
+            project_id='a7eb669e9819420ea4bd1453e672c0a7',
             created_at='1970-01-01T00:00:00.000000',
             updated_at='1970-01-01T00:00:00.000000'
         )
@@ -211,32 +215,56 @@ class Execution(resource.Resource):
     """Execution resource."""
 
     id = wtypes.text
-    "id is immutable and auto assigned."
+    "execution ID. It is immutable and auto assigned or determined by the API "
+    "client on execution creation. "
+    "If it's passed to POST method from a client it'll be assigned to the "
+    "newly created execution object, but only if an execution with such ID "
+    "doesn't exist. If it exists, then the endpoint will just return "
+    "execution properties in JSON."
+
+    workflow_id = wtypes.text
+    "workflow ID"
 
     workflow_name = wtypes.text
-    "reference to workflow definition"
+    "workflow name"
 
     workflow_namespace = wtypes.text
-    """reference to workflow namespace. The workflow namespace is also saved
+    """Workflow namespace. The workflow namespace is also saved
      under params and passed to all sub-workflow executions. When looking for
      the next sub-workflow to run, The correct workflow will be found by
      name and namespace, where the namespace can be the workflow namespace or
      the default namespace. Workflows in the same namespace as the top workflow
      will be given a higher priority."""
 
-    workflow_id = wtypes.text
-    "reference to workflow ID"
-
     description = wtypes.text
-    "description of workflow execution."
+    "description of workflow execution"
 
     params = types.jsontype
-    """params define workflow type specific parameters. For example, reverse
-     workflow takes one parameter 'task_name' that defines a target task."""
+    """'params' define workflow type specific parameters. Specific parameters
+     are:
+     'task_name' - the name of the target task. Only for reverse workflows.
+     'env' - A string value containing the name of the stored environment
+     object or a dictionary with the environment variables used during
+     workflow execution and accessible as 'env()' from within expressions
+     (YAQL or Jinja) defined in the workflow text.
+     'evaluate_env' - If present, controls whether or not Mistral should
+     recursively find and evaluate all expressions (YAQL or Jinja) within
+     the specified environment (via 'env' parameter). 'True' - evaluate
+     all expressions recursively in the environment structure. 'False' -
+     don't evaluate expressions. 'True' by default.
+    """
 
     task_execution_id = wtypes.text
     "reference to the parent task execution"
 
+    root_execution_id = wtypes.text
+    "reference to the root execution"
+
+    source_execution_id = wtypes.text
+    """reference to a workflow execution id which will signal the api to
+    perform a lookup of a current workflow_execution and create a replica
+    based on that workflow inputs and parameters"""
+
     state = wtypes.text
     "state can be one of: IDLE, RUNNING, SUCCESS, ERROR, PAUSED"
 
@@ -244,14 +272,16 @@ class Execution(resource.Resource):
     "an optional state information string"
 
     input = types.jsontype
-    "input is a JSON structure containing workflow input values."
+    "input is a JSON structure containing workflow input values"
 
     output = types.jsontype
-    "output is a workflow output."
+    "output is a workflow output"
 
     created_at = wtypes.text
     updated_at = wtypes.text
 
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
+
     @classmethod
     def sample(cls):
         return cls(id='123e4567-e89b-12d3-a456-426655440000',
@@ -259,6 +289,7 @@ class Execution(resource.Resource):
                    workflow_namespace='some_namespace',
                    workflow_id='123e4567-e89b-12d3-a456-426655441111',
                    description='this is the first execution.',
+                   project_id='40a908dbddfe48ad80a87fb30fa70a03',
                    state='SUCCESS',
                    input={},
                    output={},
@@ -309,6 +340,8 @@ class Task(resource.Resource):
     state_info = wtypes.text
     "an optional state information string"
 
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
+
     runtime_context = types.jsontype
 
     result = wtypes.text
@@ -332,6 +365,7 @@ class Task(resource.Resource):
             workflow_execution_id='123e4567-e89b-12d3-a456-426655440000',
             name='task',
             state=states.SUCCESS,
+            project_id='40a908dbddfe48ad80a87fb30fa70a03',
             runtime_context={
                 'triggered_by': [
                     {
@@ -380,6 +414,7 @@ class ActionExecution(resource.Resource):
     tags = [wtypes.text]
     name = wtypes.text
     description = wtypes.text
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
     accepted = bool
     input = types.jsontype
     output = types.jsontype
@@ -400,6 +435,7 @@ class ActionExecution(resource.Resource):
             tags=['foo', 'fee'],
             name='std.echo',
             description='My running action',
+            project_id='40a908dbddfe48ad80a87fb30fa70a03',
             accepted=True,
             input={'first_name': 'John', 'last_name': 'Doe'},
             output={'some_output': 'Hello, John Doe!'},
@@ -433,6 +469,7 @@ class CronTrigger(resource.Resource):
     workflow_id = wtypes.text
     workflow_input = types.jsontype
     workflow_params = types.jsontype
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
 
     scope = SCOPE_TYPES
 
@@ -453,6 +490,7 @@ class CronTrigger(resource.Resource):
             workflow_id='123e4567-e89b-12d3-a456-426655441111',
             workflow_input={},
             workflow_params={},
+            project_id='40a908dbddfe48ad80a87fb30fa70a03',
             scope='private',
             pattern='* * * * *',
             remaining_executions=42,
@@ -484,6 +522,7 @@ class Environment(resource.Resource):
     description = wtypes.text
     variables = types.jsontype
     scope = SCOPE_TYPES
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
     created_at = wtypes.text
     updated_at = wtypes.text
 
@@ -500,6 +539,7 @@ class Environment(resource.Resource):
                 'verbose': True
             },
             scope='private',
+            project_id='40a908dbddfe48ad80a87fb30fa70a03',
             created_at='1970-01-01T00:00:00.000000',
             updated_at='1970-01-01T00:00:00.000000'
         )
