@@ -12,16 +12,13 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo_log import log as logging
+
 import pecan
 from pecan import rest
 
 from mistral import exceptions as exc
 
 
-LOG = logging.getLogger(__name__)
-
-
 class SpecValidationController(rest.RestController):
 
     def __init__(self, parser):
@@ -37,6 +34,6 @@ class SpecValidationController(rest.RestController):
         try:
             self._parse_func(definition)
         except exc.DSLParsingException as e:
-            return {'valid': False, 'error': e.message}
+            return {'valid': False, 'error': str(e)}
 
         return {'valid': True}
