@@ -228,6 +228,17 @@ scheduler_opts = [
             'delay limited by this property.'
         )
     ),
+    cfg.IntOpt(
+        'batch_size',
+        default=None,
+        min=1,
+        help=(
+            'The max number of delayed calls will be selected during '
+            'a scheduler iteration. '
+            'If this property equals None then there is no '
+            'restriction on selection.'
+        )
+    )
 ]
 
 cron_trigger_opts = [
@@ -240,6 +251,20 @@ cron_trigger_opts = [
             ' performance.'
         )
     ),
+    cfg.IntOpt(
+        'execution_interval',
+        default=1,
+        min=1,
+        help=(
+            'This setting defines how frequently Mistral checks for cron ',
+            'triggers that need execution. By default this is every second ',
+            'which can lead to high system load. Increasing the number will ',
+            'reduce the load but also limit the minimum freqency. For ',
+            'example, a cron trigger can be configured to run every second ',
+            'but if the execution_interval is set to 60, it will only run ',
+            'once per minute.'
+        )
+    )
 ]
 
 event_engine_opts = [
@@ -250,6 +275,13 @@ event_engine_opts = [
                'identifier. It is not necessarily a hostname, '
                'FQDN, or IP address.')
     ),
+    cfg.HostAddressOpt(
+        'listener_pool_name',
+        default='events',
+        help=_('Name of the event engine\'s listener pool. This can be an'
+               ' opaque identifier. It is used for identifying the group'
+               ' of event engine listeners in oslo.messaging.')
+    ),
     cfg.StrOpt(
         'topic',
         default='mistral_event_engine',
@@ -356,7 +388,7 @@ openstack_actions_opts = [
     ),
     cfg.ListOpt(
         'modules-support-region',
-        default=['nova', 'glance', 'ceilometer', 'heat', 'neutron', 'cinder',
+        default=['nova', 'glance', 'heat', 'neutron', 'cinder',
                  'trove', 'ironic', 'designate', 'murano', 'tacker', 'senlin',
                  'aodh', 'gnocchi'],
         help=_('List of module names that support region in actions.')
@@ -454,6 +486,8 @@ def list_opts():
         (ENGINE_GROUP, engine_opts),
         (EXECUTOR_GROUP, executor_opts),
         (EVENT_ENGINE_GROUP, event_engine_opts),
+        (SCHEDULER_GROUP, scheduler_opts),
+        (CRON_TRIGGER_GROUP, cron_trigger_opts),
         (PECAN_GROUP, pecan_opts),
         (COORDINATION_GROUP, coordination_opts),
         (EXECUTION_EXPIRATION_POLICY_GROUP, execution_expiration_policy_opts),
@@ -474,7 +508,7 @@ def parse_args(args=None, usage=None, default_config_files=None):
     CONF(
         args=args,
         project='mistral',
-        version=version,
+        version=version.version_string,
         usage=usage,
         default_config_files=default_config_files
     )
