@@ -53,8 +53,8 @@ def end_tx():
 
 
 @contextlib.contextmanager
-def transaction():
-    with IMPL.transaction():
+def transaction(read_only=False):
+    with IMPL.transaction(read_only):
         yield
 
 
@@ -62,10 +62,6 @@ def refresh(model):
     IMPL.refresh(model)
 
 
-def expire_all():
-    IMPL.expire_all()
-
-
 # Locking.
 
 
@@ -178,7 +174,7 @@ def load_action_definition(name):
     return IMPL.load_action_definition(name)
 
 
-def get_action_definitions(limit=None, marker=None, sort_keys=['name'],
+def get_action_definitions(limit=None, marker=None, sort_keys=None,
                            sort_dirs=None, **kwargs):
     return IMPL.get_action_definitions(
         limit=limit,
@@ -224,10 +220,6 @@ def get_action_executions(**kwargs):
     return IMPL.get_action_executions(**kwargs)
 
 
-def ensure_action_execution_exists(id):
-    return IMPL.ensure_action_execution_exists(id)
-
-
 def create_action_execution(values):
     return IMPL.create_action_execution(values)
 
@@ -259,7 +251,7 @@ def load_workflow_execution(name):
     return IMPL.load_workflow_execution(name)
 
 
-def get_workflow_executions(limit=None, marker=None, sort_keys=['created_at'],
+def get_workflow_executions(limit=None, marker=None, sort_keys=None,
                             sort_dirs=None, **kwargs):
     return IMPL.get_workflow_executions(
         limit=limit,
@@ -270,10 +262,6 @@ def get_workflow_executions(limit=None, marker=None, sort_keys=['created_at'],
     )
 
 
-def ensure_workflow_execution_exists(id):
-    return IMPL.ensure_workflow_execution_exists(id)
-
-
 def create_workflow_execution(values):
     return IMPL.create_workflow_execution(values)
 
@@ -309,7 +297,7 @@ def load_task_execution(id):
     return IMPL.load_task_execution(id)
 
 
-def get_task_executions(limit=None, marker=None, sort_keys=['created_at'],
+def get_task_executions(limit=None, marker=None, sort_keys=None,
                         sort_dirs=None, **kwargs):
     return IMPL.get_task_executions(
         limit=limit,
@@ -324,10 +312,6 @@ def get_completed_task_executions(**kwargs):
     return IMPL.get_completed_task_executions(**kwargs)
 
 
-def get_completed_task_executions_as_batches(**kwargs):
-    return IMPL.get_completed_task_executions_as_batches(**kwargs)
-
-
 def get_incomplete_task_executions(**kwargs):
     return IMPL.get_incomplete_task_executions(**kwargs)
 
@@ -362,8 +346,8 @@ def update_task_execution_state(**kwargs):
 
 # Delayed calls.
 
-def get_delayed_calls_to_start(time):
-    return IMPL.get_delayed_calls_to_start(time)
+def get_delayed_calls_to_start(time, batch_size=None):
+    return IMPL.get_delayed_calls_to_start(time, batch_size)
 
 
 def create_delayed_call(values):
@@ -392,13 +376,17 @@ def delete_delayed_calls(**kwargs):
 
 # Cron triggers.
 
-def get_cron_trigger(name):
-    return IMPL.get_cron_trigger(name)
+def get_cron_trigger(identifier):
+    return IMPL.get_cron_trigger(identifier)
 
 
-def load_cron_trigger(name):
+def get_cron_trigger_by_id(id):
+    return IMPL.get_cron_trigger_by_id(id)
+
+
+def load_cron_trigger(identifier):
     """Unlike get_cron_trigger this method is allowed to return None."""
-    return IMPL.load_cron_trigger(name)
+    return IMPL.load_cron_trigger(identifier)
 
 
 def get_cron_triggers(**kwargs):
@@ -431,16 +419,17 @@ def create_cron_trigger(values):
     return IMPL.create_cron_trigger(values)
 
 
-def update_cron_trigger(name, values, query_filter=None):
-    return IMPL.update_cron_trigger(name, values, query_filter=query_filter)
+def update_cron_trigger(identifier, values, query_filter=None):
+    return IMPL.update_cron_trigger(identifier, values,
+                                    query_filter=query_filter)
 
 
-def create_or_update_cron_trigger(name, values):
-    return IMPL.create_or_update_cron_trigger(name, values)
+def create_or_update_cron_trigger(identifier, values):
+    return IMPL.create_or_update_cron_trigger(identifier, values)
 
 
-def delete_cron_trigger(name):
-    return IMPL.delete_cron_trigger(name)
+def delete_cron_trigger(identifier):
+    return IMPL.delete_cron_trigger(identifier)
 
 
 def delete_cron_triggers(**kwargs):
@@ -458,7 +447,7 @@ def load_environment(name):
     return IMPL.load_environment(name)
 
 
-def get_environments(limit=None, marker=None, sort_keys=['name'],
+def get_environments(limit=None, marker=None, sort_keys=None,
                      sort_dirs=None, **kwargs):
 
     return IMPL.get_environments(
@@ -561,10 +550,6 @@ def delete_event_triggers(**kwargs):
     return IMPL.delete_event_triggers(**kwargs)
 
 
-def ensure_event_trigger_exists(id):
-    return IMPL.ensure_event_trigger_exists(id)
-
-
 # Locks.
 
 def create_named_lock(name):
