@@ -107,12 +107,15 @@ def end_tx():
 
 
 @contextlib.contextmanager
-def transaction():
+def transaction(read_only=False):
     start_tx()
 
     try:
         yield
-        commit_tx()
+        if read_only:
+            rollback_tx()
+        else:
+            commit_tx()
     finally:
         end_tx()
 
@@ -122,11 +125,6 @@ def refresh(model, session=None):
     session.refresh(model)
 
 
-@b.session_aware()
-def expire_all(session=None):
-    session.expire_all()
-
-
 @b.session_aware()
 def acquire_lock(model, id, session=None):
     # Expire all so all objects queried after lock is acquired
@@ -182,7 +180,7 @@ def update_on_match(id, specimen, values, session=None):
     except oslo_sqlalchemy.update_match.NoRowsMatched:
         LOG.info(
             "Can't change state of persistent object "
-            "because it has already been changed. [model_class=%s, id=%s, "
+            "because it has already been changed. [model_class=%, id=%s, "
             "specimen=%s, values=%s]",
             model_class, id, specimen, values
         )
@@ -228,7 +226,10 @@ def _paginate_query(model, limit=None, marker=None, sort_keys=None,
 
     sort_keys = sort_keys if sort_keys else []
 
-    if 'id' not in sort_keys:
+    # We should add sorting by id only if we use pagination or when
+    # there is no specified ordering criteria. Otherwise
+    # we can omit it to increase the performance.
+    if not sort_keys or (marker or limit) and 'id' not in sort_keys:
         sort_keys.append('id')
         sort_dirs.append('asc') if sort_dirs else None
 
@@ -274,28 +275,6 @@ def _get_collection(model, insecure=False, limit=None, marker=None,
     return query.all()
 
 
-def _get_collection_sorted_by_name(model, insecure=False, fields=None,
-                                   sort_keys=['name'], **kwargs):
-    return _get_collection(
-        model=model,
-        insecure=insecure,
-        sort_keys=sort_keys,
-        fields=fields,
-        **kwargs
-    )
-
-
-def _get_collection_sorted_by_time(model, insecure=False, fields=None,
-                                   sort_keys=['created_at'], **kwargs):
-    return _get_collection(
-        model=model,
-        insecure=insecure,
-        sort_keys=sort_keys,
-        fields=fields,
-        **kwargs
-    )
-
-
 def _get_db_object_by_name(model, name, filter_=None, order_by=None):
 
     query = _secure_query(model)
@@ -310,34 +289,12 @@ def _get_db_object_by_name(model, name, filter_=None, order_by=None):
     return query.filter(final_filter).first()
 
 
-def _get_wf_object_by_name_and_namespace(model, name, namespace=None):
-
-    query = _secure_query(model)
-    filter_ = model.name == name
-
-    if namespace is not None:
-        filter_ = sa.and_(filter_, model.namespace.in_([namespace, '']))
-
-        # Give priority to objects not in the default namespace.
-        query = query.order_by(model.namespace.desc())
-
-    return query.filter(filter_).first()
-
-
 def _get_db_object_by_id(model, id, insecure=False):
     query = b.model_query(model) if insecure else _secure_query(model)
 
     return query.filter_by(id=id).first()
 
 
-def _get_db_object_by_name_or_id(model, identifier, insecure=False):
-    return _get_db_object_by_name_and_namespace_or_id(
-        model,
-        identifier,
-        insecure=insecure
-    )
-
-
 def _get_db_object_by_name_and_namespace_or_id(model, identifier,
                                                namespace=None, insecure=False):
 
@@ -399,7 +356,7 @@ def load_workbook(name, session=None):
 
 @b.session_aware()
 def get_workbooks(session=None, **kwargs):
-    return _get_collection_sorted_by_name(models.Workbook, **kwargs)
+    return _get_collection(models.Workbook, **kwargs)
 
 
 @b.session_aware()
@@ -437,9 +394,13 @@ def create_or_update_workbook(name, values, session=None):
 
 @b.session_aware()
 def delete_workbook(name, session=None):
-    wb = get_workbook(name)
+    count = _secure_query(models.Workbook).filter(
+        models.Workbook.name == name).delete()
 
-    session.delete(wb)
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "Workbook not found [workbook_name=%s]" % name
+        )
 
 
 @b.session_aware()
@@ -506,15 +467,13 @@ def load_workflow_definition(name, namespace='', session=None):
 
 
 @b.session_aware()
-def get_workflow_definitions(sort_keys=['created_at'], fields=None,
-                             session=None, **kwargs):
+def get_workflow_definitions(fields=None, session=None, **kwargs):
     if fields and 'input' in fields:
         fields.remove('input')
         fields.append('spec')
 
-    return _get_collection_sorted_by_name(
+    return _get_collection(
         model=models.WorkflowDefinition,
-        sort_keys=sort_keys,
         fields=fields,
         **kwargs
     )
@@ -630,7 +589,7 @@ def get_action_definition_by_id(id, session=None):
 
 @b.session_aware()
 def get_action_definition(identifier, session=None):
-    a_def = _get_db_object_by_name_or_id(
+    a_def = _get_db_object_by_name_and_namespace_or_id(
         models.ActionDefinition,
         identifier
     )
@@ -650,10 +609,7 @@ def load_action_definition(name, session=None):
 
 @b.session_aware()
 def get_action_definitions(session=None, **kwargs):
-    return _get_collection_sorted_by_name(
-        model=models.ActionDefinition,
-        **kwargs
-    )
+    return _get_collection(model=models.ActionDefinition, **kwargs)
 
 
 @b.session_aware()
@@ -720,11 +676,6 @@ def load_action_execution(id, session=None):
     return _get_db_object_by_id(models.ActionExecution, id)
 
 
-@b.session_aware()
-def ensure_action_execution_exists(id, session=None):
-    get_action_execution(id)
-
-
 @b.session_aware()
 def get_action_executions(session=None, **kwargs):
     return _get_action_executions(**kwargs)
@@ -765,9 +716,13 @@ def create_or_update_action_execution(id, values, session=None):
 
 @b.session_aware()
 def delete_action_execution(id, session=None):
-    a_ex = get_action_execution(id)
+    count = _secure_query(models.ActionExecution).filter(
+        models.ActionExecution.id == id).delete()
 
-    session.delete(a_ex)
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "ActionExecution not found [id=%s]" % id
+        )
 
 
 @b.session_aware()
@@ -776,7 +731,7 @@ def delete_action_executions(session=None, **kwargs):
 
 
 def _get_action_executions(**kwargs):
-    return _get_collection_sorted_by_time(models.ActionExecution, **kwargs)
+    return _get_collection(models.ActionExecution, **kwargs)
 
 
 # Workflow executions.
@@ -804,17 +759,9 @@ def load_workflow_execution(id, session=None):
     return _get_db_object_by_id(models.WorkflowExecution, id)
 
 
-@b.session_aware()
-def ensure_workflow_execution_exists(id, session=None):
-    get_workflow_execution(id)
-
-
 @b.session_aware()
 def get_workflow_executions(session=None, **kwargs):
-    return _get_collection_sorted_by_time(
-        models.WorkflowExecution,
-        **kwargs
-    )
+    return _get_collection(models.WorkflowExecution, **kwargs)
 
 
 @b.session_aware()
@@ -827,7 +774,9 @@ def create_workflow_execution(values, session=None):
         wf_ex.save(session=session)
     except db_exc.DBDuplicateEntry as e:
         raise exc.DBDuplicateEntryError(
-            "Duplicate entry for WorkflowExecution: %s" % e.columns
+            "Duplicate entry for WorkflowExecution with ID {value} ".format(
+                value=e.value
+            )
         )
 
     return wf_ex
@@ -854,9 +803,17 @@ def create_or_update_workflow_execution(id, values, session=None):
 
 @b.session_aware()
 def delete_workflow_execution(id, session=None):
-    wf_ex = get_workflow_execution(id)
+    model = models.WorkflowExecution
+    insecure = context.ctx().is_admin
+    query = b.model_query(model) if insecure else _secure_query(model)
 
-    session.delete(wf_ex)
+    count = query.filter(
+        models.WorkflowExecution.id == id).delete()
+
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "WorkflowExecution not found [id=%s]" % id
+        )
 
 
 @b.session_aware()
@@ -891,7 +848,7 @@ def load_task_execution(id, session=None):
 
 @b.session_aware()
 def get_task_executions(session=None, **kwargs):
-    return _get_task_executions(**kwargs)
+    return _get_collection(models.TaskExecution, **kwargs)
 
 
 def _get_completed_task_executions_query(kwargs):
@@ -917,30 +874,6 @@ def get_completed_task_executions(session=None, **kwargs):
     return query.all()
 
 
-@b.session_aware()
-def get_completed_task_executions_as_batches(session=None, **kwargs):
-    # NOTE: Using batch querying seriously allows to optimize memory
-    # consumption on operations when we need to iterate through
-    # a list of task executions and do some processing like merging
-    # their inbound contexts. If we don't use batches Mistral has to
-    # hold all the collection (that can be large) in memory.
-    # Using a generator that returns batches lets GC to collect a
-    # batch of task executions that has already been processed.
-    query = _get_completed_task_executions_query(kwargs)
-
-    # Batch size 20 may be arguable but still seems reasonable: it's big
-    # enough to keep the total number of DB hops small (say for 100 tasks
-    # we'll need only 5) and small enough not to drastically increase
-    # memory footprint if the number of tasks is big like several hundreds.
-    batch_size = 20
-    idx = 0
-
-    while idx < query.count():
-        yield query.slice(idx, idx + batch_size).all()
-
-        idx += batch_size
-
-
 def _get_incomplete_task_executions_query(kwargs):
     query = b.model_query(models.TaskExecution)
 
@@ -1008,9 +941,13 @@ def create_or_update_task_execution(id, values, session=None):
 
 @b.session_aware()
 def delete_task_execution(id, session=None):
-    task_ex = get_task_execution(id)
+    count = _secure_query(models.TaskExecution).filter(
+        models.TaskExecution.id == id).delete()
 
-    session.delete(task_ex)
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "Task execution not found [id=%s]" % id
+        )
 
 
 @b.session_aware()
@@ -1018,10 +955,6 @@ def delete_task_executions(session=None, **kwargs):
     return _delete_all(models.TaskExecution, **kwargs)
 
 
-def _get_task_executions(**kwargs):
-    return _get_collection_sorted_by_time(models.TaskExecution, **kwargs)
-
-
 def update_task_execution_state(id, cur_state, state):
     specimen = models.TaskExecution(id=id, state=cur_state)
 
@@ -1047,18 +980,25 @@ def create_delayed_call(values, session=None):
 
 @b.session_aware()
 def delete_delayed_call(id, session=None):
-    delayed_call = get_delayed_call(id)
+    # It's safe to use insecure query here because users can't access
+    # delayed calls.
+    count = b.model_query(models.DelayedCall).filter(
+        models.DelayedCall.id == id).delete()
 
-    session.delete(delayed_call)
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "Delayed Call not found [id=%s]" % id
+        )
 
 
 @b.session_aware()
-def get_delayed_calls_to_start(time, session=None):
+def get_delayed_calls_to_start(time, batch_size=None, session=None):
     query = b.model_query(models.DelayedCall)
 
     query = query.filter(models.DelayedCall.execution_time < time)
     query = query.filter_by(processing=False)
     query = query.order_by(models.DelayedCall.execution_time)
+    query = query.limit(batch_size)
 
     return query.all()
 
@@ -1104,10 +1044,7 @@ def get_delayed_call(id, session=None):
 
 @b.session_aware()
 def get_delayed_calls(session=None, **kwargs):
-    return _get_collection(
-        model=models.DelayedCall,
-        **kwargs
-    )
+    return _get_collection(model=models.DelayedCall, **kwargs)
 
 
 @b.session_aware()
@@ -1159,31 +1096,49 @@ def _get_completed_root_executions_query(columns):
 
 
 @b.session_aware()
-def get_cron_trigger(name, session=None):
-    cron_trigger = _get_db_object_by_name(models.CronTrigger, name)
+def get_cron_trigger(identifier, session=None):
+    ctx = context.ctx()
+
+    cron_trigger = _get_db_object_by_name_and_namespace_or_id(
+        models.CronTrigger,
+        identifier,
+        insecure=ctx.is_admin
+    )
 
     if not cron_trigger:
         raise exc.DBEntityNotFoundError(
-            "Cron trigger not found [name=%s]" % name
+            "Cron trigger not found [identifier=%s]" % identifier
         )
 
     return cron_trigger
 
 
 @b.session_aware()
-def load_cron_trigger(name, session=None):
-    return _get_db_object_by_name(models.CronTrigger, name)
+def get_cron_trigger_by_id(id, session=None):
+    ctx = context.ctx()
+    cron_trigger = _get_db_object_by_id(models.CronTrigger, id,
+                                        insecure=ctx.is_admin)
+    if not cron_trigger:
+        raise exc.DBEntityNotFoundError(
+            "Cron trigger not found [id=%s]" % id
+        )
+
+    return cron_trigger
 
 
 @b.session_aware()
-def get_cron_triggers(insecure=False, session=None, **kwargs):
-    return _get_collection_sorted_by_name(
+def load_cron_trigger(identifier, session=None):
+    return _get_db_object_by_name_and_namespace_or_id(
         models.CronTrigger,
-        insecure=insecure,
-        **kwargs
+        identifier
     )
 
 
+@b.session_aware()
+def get_cron_triggers(session=None, **kwargs):
+    return _get_collection(models.CronTrigger, **kwargs)
+
+
 @b.session_aware()
 def get_next_cron_triggers(time, session=None):
     query = b.model_query(models.CronTrigger)
@@ -1218,8 +1173,8 @@ def create_cron_trigger(values, session=None):
 
 
 @b.session_aware()
-def update_cron_trigger(name, values, session=None, query_filter=None):
-    cron_trigger = get_cron_trigger(name)
+def update_cron_trigger(identifier, values, session=None, query_filter=None):
+    cron_trigger = get_cron_trigger(identifier)
 
     if query_filter:
         try:
@@ -1251,20 +1206,24 @@ def update_cron_trigger(name, values, session=None, query_filter=None):
 
 
 @b.session_aware()
-def create_or_update_cron_trigger(name, values, session=None):
-    cron_trigger = _get_db_object_by_name(models.CronTrigger, name)
+def create_or_update_cron_trigger(identifier, values, session=None):
+    cron_trigger = _get_db_object_by_name_and_namespace_or_id(
+        models.CronTrigger,
+        identifier
+    )
 
     if not cron_trigger:
         return create_cron_trigger(values)
     else:
-        updated, _ = update_cron_trigger(name, values)
+        updated, _ = update_cron_trigger(identifier, values)
         return updated
 
 
 @b.session_aware()
-def delete_cron_trigger(name, session=None):
-    cron_trigger = get_cron_trigger(name)
+def delete_cron_trigger(identifier, session=None):
+    cron_trigger = get_cron_trigger(identifier)
 
+    m_dbutils.check_db_obj_access(cron_trigger)
     # Delete the cron trigger by ID and get the affected row count.
     table = models.CronTrigger.__table__
     result = session.execute(
@@ -1300,7 +1259,7 @@ def load_environment(name, session=None):
 
 @b.session_aware()
 def get_environments(session=None, **kwargs):
-    return _get_collection_sorted_by_name(models.Environment, **kwargs)
+    return _get_collection(models.Environment, **kwargs)
 
 
 @b.session_aware()
@@ -1340,9 +1299,13 @@ def create_or_update_environment(name, values, session=None):
 
 @b.session_aware()
 def delete_environment(name, session=None):
-    env = get_environment(name)
+    count = _secure_query(models.Environment).filter(
+        models.Environment.name == name).delete()
 
-    session.delete(env)
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "Environment not found [name=%s]" % name
+        )
 
 
 @b.session_aware()
@@ -1475,22 +1438,20 @@ def update_resource_member(resource_id, res_type, member_id, values,
 
 @b.session_aware()
 def delete_resource_member(resource_id, res_type, member_id, session=None):
-    query = _secure_query(models.ResourceMember).filter_by(
-        resource_type=res_type
-    )
-
-    res_member = query.filter(_get_criterion(resource_id, member_id)).first()
-
-    if not res_member:
-        raise exc.DBEntityNotFoundError(
-            "Resource member not found [resource_id=%s, member_id=%s]" %
-            (resource_id, member_id)
-        )
+    query = _secure_query(models.ResourceMember).\
+        filter_by(resource_type=res_type).\
+        filter(_get_criterion(resource_id, member_id))
 
     # TODO(kong): Check association with cron triggers when deleting a workflow
     # member which is in 'accepted' status.
 
-    session.delete(res_member)
+    count = query.delete()
+
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "Resource member not found [resource_id=%s, member_id=%s]" %
+            (resource_id, member_id)
+        )
 
 
 @b.session_aware()
@@ -1514,7 +1475,7 @@ def _get_accepted_resources(res_type):
 
 @b.session_aware()
 def get_event_trigger(id, insecure=False, session=None):
-    event_trigger = _get_event_trigger(id, insecure)
+    event_trigger = _get_db_object_by_id(models.EventTrigger, id, insecure)
 
     if not event_trigger:
         raise exc.DBEntityNotFoundError(
@@ -1526,16 +1487,12 @@ def get_event_trigger(id, insecure=False, session=None):
 
 @b.session_aware()
 def load_event_trigger(id, insecure=False, session=None):
-    return _get_event_trigger(id, insecure)
+    return _get_db_object_by_id(models.EventTrigger, id, insecure)
 
 
 @b.session_aware()
-def get_event_triggers(insecure=False, session=None, **kwargs):
-    return _get_collection_sorted_by_time(
-        model=models.EventTrigger,
-        insecure=insecure,
-        **kwargs
-    )
+def get_event_triggers(session=None, **kwargs):
+    return _get_collection(model=models.EventTrigger, **kwargs)
 
 
 @b.session_aware()
@@ -1572,9 +1529,15 @@ def update_event_trigger(id, values, session=None):
 
 @b.session_aware()
 def delete_event_trigger(id, session=None):
-    event_trigger = get_event_trigger(id)
+    # It's safe to use insecure query here because users can't access
+    # delayed calls.
+    count = b.model_query(models.EventTrigger).filter(
+        models.EventTrigger.id == id).delete()
 
-    session.delete(event_trigger)
+    if count == 0:
+        raise exc.DBEntityNotFoundError(
+            "Event trigger not found [id=%s]." % id
+        )
 
 
 @b.session_aware()
@@ -1582,18 +1545,6 @@ def delete_event_triggers(session=None, **kwargs):
     return _delete_all(models.EventTrigger, **kwargs)
 
 
-def _get_event_trigger(id, insecure=False):
-    if insecure:
-        return b.model_query(models.EventTrigger).filter_by(id=id).first()
-    else:
-        return _get_db_object_by_id(models.EventTrigger, id)
-
-
-@b.session_aware()
-def ensure_event_trigger_exists(id, session=None):
-    get_event_trigger(id)
-
-
 # Locks.
 
 @b.session_aware()
