@@ -15,14 +15,14 @@
 
 import hashlib
 import json
-import sqlalchemy as sa
-from sqlalchemy import event
-from sqlalchemy.orm import backref
-from sqlalchemy.orm import relationship
 import sys
 
 from oslo_config import cfg
 from oslo_log import log as logging
+import sqlalchemy as sa
+from sqlalchemy import event
+from sqlalchemy.orm import backref
+from sqlalchemy.orm import relationship
 
 from mistral.db.sqlalchemy import model_base as mb
 from mistral.db.sqlalchemy import types as st
@@ -317,6 +317,14 @@ sa.Index(
     'task_execution_id'
 )
 
+# Many-to-one for 'WorkflowExecution' and 'WorkflowExecution'
+
+WorkflowExecution.root_execution_id = sa.Column(
+    sa.String(36),
+    sa.ForeignKey(WorkflowExecution.id, ondelete='SET NULL'),
+    nullable=True
+)
+
 # Many-to-one for 'TaskExecution' and 'WorkflowExecution'.
 
 TaskExecution.workflow_execution_id = sa.Column(
@@ -337,6 +345,11 @@ sa.Index(
     TaskExecution.workflow_execution_id
 )
 
+sa.Index(
+    '%s_workflow_execution_id_name' % TaskExecution.__tablename__,
+    TaskExecution.workflow_execution_id, TaskExecution.name
+)
+
 
 # Other objects.
 
