@@ -91,7 +91,8 @@ class Action(object):
         self.action_ex.state = state
 
     @abc.abstractmethod
-    def schedule(self, input_dict, target, index=0, desc='', safe_rerun=False):
+    def schedule(self, input_dict, target, index=0, desc='', safe_rerun=False,
+                 timeout=None):
         """Schedule action run.
 
         This method is needed to schedule action run so its result can
@@ -100,6 +101,8 @@ class Action(object):
         executor asynchrony when executor doesn't immediately send a
         result).
 
+        :param timeout: a period of time in seconds after which execution of
+            action will be interrupted
         :param input_dict: Action input.
         :param target: Target (group of action executors).
         :param index: Action execution index. Makes sense for some types.
@@ -111,13 +114,15 @@ class Action(object):
 
     @abc.abstractmethod
     def run(self, input_dict, target, index=0, desc='', save=True,
-            safe_rerun=False):
+            safe_rerun=False, timeout=None):
         """Immediately run action.
 
         This method runs method w/o scheduling its run for a later time.
         From engine perspective action will be processed in synchronous
         mode.
 
+        :param timeout: a period of time in seconds after which execution of
+            action will be interrupted
         :param input_dict: Action input.
         :param target: Target (group of action executors).
         :param index: Action execution index. Makes sense for some types.
@@ -177,11 +182,6 @@ class Action(object):
             # state within the current session.
             self.task_ex.action_executions.append(self.action_ex)
 
-    def _inject_action_ctx_for_validating(self, input_dict):
-        if a_m.has_action_context(
-                self.action_def.action_class, self.action_def.attributes):
-            input_dict.update(a_m.get_empty_action_context())
-
     @profiler.trace('action-log-result', hide_args=True)
     def _log_result(self, prev_state, result):
         state = self.action_ex.state
@@ -230,7 +230,8 @@ class PythonAction(Action):
         self._log_result(prev_state, result)
 
     @profiler.trace('action-schedule', hide_args=True)
-    def schedule(self, input_dict, target, index=0, desc='', safe_rerun=False):
+    def schedule(self, input_dict, target, index=0, desc='', safe_rerun=False,
+                 timeout=None):
         assert not self.action_ex
 
         # Assign the action execution ID here to minimize database calls.
@@ -239,8 +240,6 @@ class PythonAction(Action):
         # DB object is created.
         action_ex_id = utils.generate_unicode_uuid()
 
-        self._insert_action_context(action_ex_id, input_dict)
-
         self._create_action_execution(
             self._prepare_input(input_dict),
             self._prepare_runtime_context(index, safe_rerun),
@@ -248,15 +247,19 @@ class PythonAction(Action):
             action_ex_id=action_ex_id
         )
 
+        execution_context = self._prepare_execution_context()
+
         action_queue.schedule_run_action(
             self.action_ex,
             self.action_def,
-            target
+            target,
+            execution_context,
+            timeout=timeout
         )
 
     @profiler.trace('action-run', hide_args=True)
     def run(self, input_dict, target, index=0, desc='', save=True,
-            safe_rerun=False):
+            safe_rerun=False, timeout=None):
         assert not self.action_ex
 
         input_dict = self._prepare_input(input_dict)
@@ -268,8 +271,6 @@ class PythonAction(Action):
         # DB object is created.
         action_ex_id = utils.generate_unicode_uuid()
 
-        self._insert_action_context(action_ex_id, input_dict, save=save)
-
         if save:
             self._create_action_execution(
                 input_dict,
@@ -280,14 +281,18 @@ class PythonAction(Action):
 
         executor = exe.get_executor(cfg.CONF.executor.type)
 
+        execution_context = self._prepare_execution_context()
+
         result = executor.run_action(
             self.action_ex.id if self.action_ex else None,
             self.action_def.action_class,
             self.action_def.attributes or {},
             input_dict,
-            safe_rerun=safe_rerun,
+            safe_rerun,
+            execution_context,
             target=target,
-            async_=False
+            async_=False,
+            timeout=timeout
         )
 
         return self._prepare_output(result)
@@ -300,8 +305,6 @@ class PythonAction(Action):
         return a.is_sync()
 
     def validate_input(self, input_dict):
-        if self.action_def.action_class:
-            self._inject_action_ctx_for_validating(input_dict)
 
         # NOTE(kong): Don't validate action input if action initialization
         # method contains ** argument.
@@ -317,6 +320,23 @@ class PythonAction(Action):
             self.action_def.action_class
         )
 
+    def _prepare_execution_context(self):
+
+        exc_ctx = {}
+
+        if self.task_ex:
+            wf_ex = self.task_ex.workflow_execution
+            exc_ctx['workflow_execution_id'] = wf_ex.id
+            exc_ctx['task_id'] = self.task_ex.id
+            exc_ctx['workflow_name'] = wf_ex.name
+
+        if self.action_ex:
+            exc_ctx['action_execution_id'] = self.action_ex.id
+            callback_url = '/v2/action_executions/%s' % self.action_ex.id
+            exc_ctx['callback_url'] = callback_url
+
+        return exc_ctx
+
     def _prepare_input(self, input_dict):
         """Template method to do manipulations with input parameters.
 
@@ -339,24 +359,6 @@ class PythonAction(Action):
         """
         return {'index': index, 'safe_rerun': safe_rerun}
 
-    def _insert_action_context(self, action_ex_id, input_dict, save=True):
-        """Template method to prepare action context.
-
-        It inserts the action context in the input if required
-        runtime context.
-        """
-        # we need to push action context to all actions. It's related to
-        # https://blueprints.launchpad.net/mistral/+spec/mistral-custom-actions-api
-        has_action_context = a_m.has_action_context(
-            self.action_def.action_class,
-            self.action_def.attributes or {}
-        )
-
-        if has_action_context:
-            input_dict.update(
-                a_m.get_action_context(self.task_ex, action_ex_id, save=save)
-            )
-
 
 class AdHocAction(PythonAction):
     """Ad-hoc action."""
@@ -365,12 +367,18 @@ class AdHocAction(PythonAction):
                  wf_ctx=None):
         self.action_spec = spec_parser.get_action_spec(action_def.spec)
 
-        base_action_def = db_api.get_action_definition(
-            self.action_spec.get_base()
-        )
+        try:
+            base_action_def = db_api.get_action_definition(
+                self.action_spec.get_base()
+            )
+        except exc.DBEntityNotFoundError:
+            raise exc.InvalidActionException(
+                "Failed to find action [action_name=%s]" %
+                self.action_spec.get_base()
+            )
+
         base_action_def = self._gather_base_actions(
-            action_def,
-            base_action_def
+            action_def, base_action_def
         )
 
         super(AdHocAction, self).__init__(
@@ -410,17 +418,11 @@ class AdHocAction(PythonAction):
             base_input_expr = action_spec.get_base_input()
 
             if base_input_expr:
-                wf_ex = (
-                    self.task_ex.workflow_execution if self.task_ex else None
-                )
-
                 ctx_view = data_flow.ContextView(
                     base_input_dict,
                     self.task_ctx,
-                    data_flow.get_workflow_environment_dict(wf_ex),
                     self.wf_ctx
                 )
-
                 base_input_dict = expr.evaluate_recursively(
                     base_input_expr,
                     ctx_view
@@ -442,10 +444,8 @@ class AdHocAction(PythonAction):
 
                 if transformer is not None:
                     result = ml_actions.Result(
-                        data=expr.evaluate_recursively(
-                            transformer,
-                            result.data
-                        ),
+                        data=expr.evaluate_recursively(transformer,
+                                                       result.data),
                         error=result.error
                     )
 
@@ -490,7 +490,12 @@ class AdHocAction(PythonAction):
             self.adhoc_action_defs.append(base)
 
             base_name = base.spec['base']
-            base = db_api.get_action_definition(base_name)
+            try:
+                base = db_api.get_action_definition(base_name)
+            except exc.DBEntityNotFoundError:
+                raise exc.InvalidActionException(
+                    "Failed to find action [action_name=%s]" % base_name
+                )
 
         # if the action is repeated
         if base.name in action_names:
@@ -515,7 +520,8 @@ class WorkflowAction(Action):
         pass
 
     @profiler.trace('workflkow-action-schedule', hide_args=True)
-    def schedule(self, input_dict, target, index=0, desc='', safe_rerun=False):
+    def schedule(self, input_dict, target, index=0, desc='', safe_rerun=False,
+                 timeout=None):
         assert not self.action_ex
 
         parent_wf_ex = self.task_ex.workflow_execution
@@ -547,6 +553,10 @@ class WorkflowAction(Action):
             'namespace': parent_wf_ex.params['namespace']
         }
 
+        if 'env' in parent_wf_ex.params:
+            wf_params['env'] = parent_wf_ex.params['env']
+            wf_params['evaluate_env'] = parent_wf_ex.params.get('evaluate_env')
+
         for k, v in list(input_dict.items()):
             if k not in wf_spec.get_input():
                 wf_params[k] = v
@@ -555,6 +565,7 @@ class WorkflowAction(Action):
         wf_handler.start_workflow(
             wf_def.id,
             wf_def.namespace,
+            None,
             input_dict,
             "sub-workflow execution",
             wf_params
@@ -562,7 +573,7 @@ class WorkflowAction(Action):
 
     @profiler.trace('workflow-action-run', hide_args=True)
     def run(self, input_dict, target, index=0, desc='', save=True,
-            safe_rerun=True):
+            safe_rerun=True, timeout=None):
         raise NotImplementedError('Does not apply to this WorkflowAction.')
 
     def is_sync(self, input_dict):
