@@ -28,14 +28,16 @@ class Engine(object):
     """Engine interface."""
 
     @abc.abstractmethod
-    def start_workflow(self, wf_identifier, wf_namespace='', wf_input=None,
-                       description='', **params):
+    def start_workflow(self, wf_identifier, wf_namespace='', wf_ex_id=None,
+                       wf_input=None, description='', **params):
         """Starts the specified workflow.
 
         :param wf_identifier: Workflow ID or name. Workflow ID is recommended,
             workflow name will be deprecated since Mitaka.
+        :param wf_namespace: Workflow namespace.
         :param wf_input: Workflow input data as a dictionary.
-        :param wf_namespace: Workflow input data as a dictionary.
+        :param wf_ex_id: Workflow execution id. If passed, it will be set
+            in the new execution object.
         :param description: Execution description.
         :param params: Additional workflow type specific parameters.
         :return: Workflow execution object.
@@ -150,7 +152,6 @@ class TaskPolicy(object):
 
         ctx_view = data_flow.ContextView(
             task_ex.in_context,
-            data_flow.get_workflow_environment_dict(wf_ex),
             wf_ex.context,
             wf_ex.input
         )
@@ -169,7 +170,6 @@ class TaskPolicy(object):
 
         ctx_view = data_flow.ContextView(
             task_ex.in_context,
-            data_flow.get_workflow_environment_dict(wf_ex),
             wf_ex.context,
             wf_ex.input
         )
