@@ -34,26 +34,37 @@ from mistral.workflow import states
 
 
 class DefaultEngine(base.Engine):
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     @profiler.trace('engine-start-workflow', hide_args=True)
-    def start_workflow(self, wf_identifier, wf_namespace='', wf_input=None,
-                       description='', **params):
+    def start_workflow(self, wf_identifier, wf_namespace='', wf_ex_id=None,
+                       wf_input=None, description='', **params):
         if wf_namespace:
             params['namespace'] = wf_namespace
 
-        with db_api.transaction():
-            wf_ex = wf_handler.start_workflow(
-                wf_identifier,
-                wf_namespace,
-                wf_input or {},
-                description,
-                params
-            )
+        try:
+            with db_api.transaction():
+                wf_ex = wf_handler.start_workflow(
+                    wf_identifier,
+                    wf_namespace,
+                    wf_ex_id,
+                    wf_input or {},
+                    description,
+                    params
+                )
 
-            return wf_ex.get_clone()
+                return wf_ex.get_clone()
 
-    @db_utils.retry_on_deadlock
+        except exceptions.DBDuplicateEntryError:
+            # NOTE(akovi): the workflow execution with a provided
+            # wf_ex_id may already exist. In this case, simply
+            # return the existing entity.
+            with db_api.transaction():
+                wf_ex = db_api.get_workflow_execution(wf_ex_id)
+
+                return wf_ex.get_clone()
+
+    @db_utils.retry_on_db_error
     @action_queue.process
     def start_action(self, action_name, action_input,
                      description=None, **params):
@@ -65,6 +76,7 @@ class DefaultEngine(base.Engine):
             sync = params.get('run_sync')
             save = params.get('save_result')
             target = params.get('target')
+            timeout = params.get('timeout')
 
             is_action_sync = action.is_sync(action_input)
 
@@ -73,17 +85,18 @@ class DefaultEngine(base.Engine):
                     "Action does not support synchronous execution.")
 
             if not sync and (save or not is_action_sync):
-                action.schedule(action_input, target)
+                action.schedule(action_input, target, timeout=timeout)
 
                 return action.action_ex.get_clone()
 
-            output = action.run(action_input, target, save=False)
+            output = action.run(action_input, target, save=False,
+                                timeout=timeout)
 
             state = states.SUCCESS if output.is_success() else states.ERROR
 
             if not save:
                 # Action execution is not created but we need to return similar
-                # object to a client anyway.
+                # object to the client anyway.
                 return db_models.ActionExecution(
                     name=action_name,
                     description=description,
@@ -105,7 +118,7 @@ class DefaultEngine(base.Engine):
 
             return db_api.create_action_execution(values)
 
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     @profiler.trace('engine-on-action-complete', hide_args=True)
     def on_action_complete(self, action_ex_id, result, wf_action=False,
@@ -120,7 +133,7 @@ class DefaultEngine(base.Engine):
 
             return action_ex.get_clone()
 
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     @profiler.trace('engine-on-action-update', hide_args=True)
     def on_action_update(self, action_ex_id, state, wf_action=False,
@@ -135,7 +148,7 @@ class DefaultEngine(base.Engine):
 
             return action_ex.get_clone()
 
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     def pause_workflow(self, wf_ex_id):
         with db_api.transaction():
@@ -145,7 +158,7 @@ class DefaultEngine(base.Engine):
 
             return wf_ex.get_clone()
 
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     def rerun_workflow(self, task_ex_id, reset=True, env=None):
         with db_api.transaction():
@@ -157,7 +170,7 @@ class DefaultEngine(base.Engine):
 
             return wf_ex.get_clone()
 
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     def resume_workflow(self, wf_ex_id, env=None):
         with db_api.transaction():
@@ -167,7 +180,7 @@ class DefaultEngine(base.Engine):
 
             return wf_ex.get_clone()
 
-    @db_utils.retry_on_deadlock
+    @db_utils.retry_on_db_error
     @action_queue.process
     def stop_workflow(self, wf_ex_id, state, message=None):
         with db_api.transaction():
