@@ -28,6 +28,8 @@ import six
 
 _CONTINUE_TASK_PATH = 'mistral.engine.policies._continue_task'
 _COMPLETE_TASK_PATH = 'mistral.engine.policies._complete_task'
+_FAIL_IF_INCOMPLETE_TASK_PATH = \
+    'mistral.engine.policies._fail_task_if_incomplete'
 
 
 def _log_task_delay(task_ex, delay_sec):
@@ -80,7 +82,7 @@ def build_wait_before_policy(policies_spec):
 
     wait_before = policies_spec.get_wait_before()
 
-    if (isinstance(wait_before, six.string_types) or wait_before > 0):
+    if isinstance(wait_before, six.string_types) or wait_before > 0:
         return WaitBeforePolicy(wait_before)
     else:
         return None
@@ -92,7 +94,7 @@ def build_wait_after_policy(policies_spec):
 
     wait_after = policies_spec.get_wait_after()
 
-    if (isinstance(wait_after, six.string_types) or wait_after > 0):
+    if isinstance(wait_after, six.string_types) or wait_after > 0:
         return WaitAfterPolicy(wait_after)
     else:
         return None
@@ -121,7 +123,7 @@ def build_timeout_policy(policies_spec):
 
     timeout_policy = policies_spec.get_timeout()
 
-    if (isinstance(timeout_policy, six.string_types) or timeout_policy > 0):
+    if isinstance(timeout_policy, six.string_types) or timeout_policy > 0:
         return TimeoutPolicy(timeout_policy)
     else:
         return None
@@ -160,7 +162,10 @@ def _ensure_context_has_key(runtime_context, key):
 class WaitBeforePolicy(base.TaskPolicy):
     _schema = {
         "properties": {
-            "delay": {"type": "integer"}
+            "delay": {
+                "type": "integer",
+                "minimum": 0
+            }
         }
     }
 
@@ -170,6 +175,10 @@ class WaitBeforePolicy(base.TaskPolicy):
     def before_task_start(self, task_ex, task_spec):
         super(WaitBeforePolicy, self).before_task_start(task_ex, task_spec)
 
+        # No need to wait for a task if delay is 0
+        if self.delay == 0:
+            return
+
         context_key = 'wait_before_policy'
 
         runtime_context = _ensure_context_has_key(
@@ -211,7 +220,10 @@ class WaitBeforePolicy(base.TaskPolicy):
 class WaitAfterPolicy(base.TaskPolicy):
     _schema = {
         "properties": {
-            "delay": {"type": "integer"}
+            "delay": {
+                "type": "integer",
+                "minimum": 0
+            }
         }
     }
 
@@ -221,6 +233,10 @@ class WaitAfterPolicy(base.TaskPolicy):
     def after_task_complete(self, task_ex, task_spec):
         super(WaitAfterPolicy, self).after_task_complete(task_ex, task_spec)
 
+        # No need to postpone a task if delay is 0
+        if self.delay == 0:
+            return
+
         context_key = 'wait_after_policy'
 
         runtime_context = _ensure_context_has_key(
@@ -265,15 +281,21 @@ class WaitAfterPolicy(base.TaskPolicy):
 class RetryPolicy(base.TaskPolicy):
     _schema = {
         "properties": {
-            "delay": {"type": "integer"},
-            "count": {"type": "integer"}
+            "delay": {
+                "type": "integer",
+                "minimum": 0
+            },
+            "count": {
+                "type": "integer",
+                "minimum": 0
+            },
         }
     }
 
     def __init__(self, count, delay, break_on, continue_on):
         self.count = count
         self.delay = delay
-        self.break_on = break_on
+        self._break_on_clause = break_on
         self._continue_on_clause = continue_on
 
     def after_task_complete(self, task_ex, task_spec):
@@ -294,6 +316,10 @@ class RetryPolicy(base.TaskPolicy):
         """
         super(RetryPolicy, self).after_task_complete(task_ex, task_spec)
 
+        # There is nothing to repeat
+        if self.count == 0:
+            return
+
         # TODO(m4dcoder): If the task_ex.action_executions and
         # task_ex.workflow_executions collection are not called,
         # then the retry_no in the runtime_context of the task_ex will not
@@ -311,7 +337,6 @@ class RetryPolicy(base.TaskPolicy):
         wf_ex = task_ex.workflow_execution
 
         ctx_view = data_flow.ContextView(
-            data_flow.get_current_task_dict(task_ex),
             data_flow.evaluate_task_outbound_context(task_ex),
             wf_ex.context,
             wf_ex.input
@@ -322,6 +347,11 @@ class RetryPolicy(base.TaskPolicy):
             ctx_view
         )
 
+        break_on_evaluation = expressions.evaluate(
+            self._break_on_clause,
+            ctx_view
+        )
+
         task_ex.runtime_context = runtime_context
 
         state = task_ex.state
@@ -351,7 +381,7 @@ class RetryPolicy(base.TaskPolicy):
 
         break_triggered = (
             task_ex.state == states.ERROR and
-            self.break_on
+            break_on_evaluation
         )
 
         if not retries_remain or break_triggered or stop_continue_flag:
@@ -376,7 +406,10 @@ class RetryPolicy(base.TaskPolicy):
 class TimeoutPolicy(base.TaskPolicy):
     _schema = {
         "properties": {
-            "delay": {"type": "integer"}
+            "delay": {
+                "type": "integer",
+                "minimum": 0
+            }
         }
     }
 
@@ -386,9 +419,13 @@ class TimeoutPolicy(base.TaskPolicy):
     def before_task_start(self, task_ex, task_spec):
         super(TimeoutPolicy, self).before_task_start(task_ex, task_spec)
 
+        # No timeout if delay is 0
+        if self.delay == 0:
+            return
+
         scheduler.schedule_call(
             None,
-            'mistral.engine.policies._fail_task_if_incomplete',
+            _FAIL_IF_INCOMPLETE_TASK_PATH,
             self.delay,
             task_ex_id=task_ex.id,
             timeout=self.delay
@@ -430,7 +467,10 @@ class PauseBeforePolicy(base.TaskPolicy):
 class ConcurrencyPolicy(base.TaskPolicy):
     _schema = {
         "properties": {
-            "concurrency": {"type": "integer"},
+            "concurrency": {
+                "type": "integer",
+                "minimum": 0
+            }
         }
     }
 
@@ -440,6 +480,9 @@ class ConcurrencyPolicy(base.TaskPolicy):
     def before_task_start(self, task_ex, task_spec):
         super(ConcurrencyPolicy, self).before_task_start(task_ex, task_spec)
 
+        if self.concurrency == 0:
+            return
+
         # This policy doesn't do anything except validating "concurrency"
         # property value and setting a variable into task runtime context.
         # This variable is then used to define how many action executions
@@ -455,7 +498,7 @@ class ConcurrencyPolicy(base.TaskPolicy):
         task_ex.runtime_context = runtime_context
 
 
-@db_utils.retry_on_deadlock
+@db_utils.retry_on_db_error
 @action_queue.process
 def _continue_task(task_ex_id):
     from mistral.engine import task_handler
@@ -464,7 +507,7 @@ def _continue_task(task_ex_id):
         task_handler.continue_task(db_api.get_task_execution(task_ex_id))
 
 
-@db_utils.retry_on_deadlock
+@db_utils.retry_on_db_error
 @action_queue.process
 def _complete_task(task_ex_id, state, state_info):
     from mistral.engine import task_handler
@@ -477,7 +520,7 @@ def _complete_task(task_ex_id, state, state_info):
         )
 
 
-@db_utils.retry_on_deadlock
+@db_utils.retry_on_db_error
 @action_queue.process
 def _fail_task_if_incomplete(task_ex_id, timeout):
     from mistral.engine import task_handler
