@@ -19,6 +19,7 @@ from oslo_log import log as logging
 from osprofiler import profiler
 import traceback as tb
 
+from mistral.db import utils as db_utils
 from mistral.db.v2 import api as db_api
 from mistral.db.v2.sqlalchemy import models
 from mistral.engine import action_queue
@@ -320,6 +321,7 @@ def _create_task(wf_ex, wf_spec, task_spec, ctx, task_ex=None,
     )
 
 
+@db_utils.retry_on_db_error
 @action_queue.process
 @profiler.trace('task-handler-refresh-task-state', hide_args=True)
 def _refresh_task_state(task_ex_id):
@@ -402,6 +404,7 @@ def _schedule_refresh_task_state(task_ex, delay=0):
     )
 
 
+@db_utils.retry_on_db_error
 @action_queue.process
 def _scheduled_on_action_complete(action_ex_id, wf_action):
     with db_api.transaction():
@@ -447,6 +450,7 @@ def schedule_on_action_complete(action_ex, delay=0):
     )
 
 
+@db_utils.retry_on_db_error
 @action_queue.process
 def _scheduled_on_action_update(action_ex_id, wf_action):
     with db_api.transaction():
