@@ -125,7 +125,7 @@ class Task(object):
         :param state: New task state.
         :param state_info: New state information (i.e. error message).
         :param processed: New "processed" flag value.
-        :return True if the state was changed as a result of this call,
+        :return: True if the state was changed as a result of this call,
             False otherwise.
         """
 
@@ -265,6 +265,8 @@ class Task(object):
         task_name = self.task_spec.get_name()
         task_type = self.task_spec.get_type()
 
+        data_flow.add_current_task_to_context(self.ctx, task_id, task_name)
+
         values = {
             'id': task_id,
             'name': task_name,
@@ -288,10 +290,6 @@ class Task(object):
 
         self.task_ex = db_api.create_task_execution(values)
 
-        # Add to collection explicitly so that it's in a proper
-        # state within the current session.
-        self.wf_ex.task_executions.append(self.task_ex)
-
         self.created = True
 
     def _get_action_defaults(self):
@@ -300,7 +298,7 @@ class Task(object):
         if not action_name:
             return {}
 
-        env = self.wf_ex.params['env']
+        env = self.wf_ex.context.get('__env', {})
 
         return env.get('__actions', {}).get(action_name, {})
 
@@ -377,13 +375,16 @@ class RegularTask(Task):
         self._schedule_actions()
 
     def _update_inbound_context(self):
-        assert self.task_ex
+        task_ex = self.task_ex
+        assert task_ex
 
         wf_ctrl = wf_base.get_controller(self.wf_ex, self.wf_spec)
 
         self.ctx = wf_ctrl.get_task_inbound_context(self.task_spec)
+        data_flow.add_current_task_to_context(self.ctx, task_ex.id,
+                                              task_ex.name)
 
-        utils.update_dict(self.task_ex.in_context, self.ctx)
+        utils.update_dict(task_ex.in_context, self.ctx)
 
     def _update_triggered_by(self):
         assert self.task_ex
@@ -423,7 +424,8 @@ class RegularTask(Task):
         action.schedule(
             input_dict,
             target,
-            safe_rerun=self.task_spec.get_safe_rerun()
+            safe_rerun=self.task_spec.get_safe_rerun(),
+            timeout=self._get_timeout()
         )
 
     @profiler.trace('regular-task-get-target', hide_args=True)
@@ -431,7 +433,6 @@ class RegularTask(Task):
         ctx_view = data_flow.ContextView(
             input_dict,
             self.ctx,
-            data_flow.get_workflow_environment_dict(self.wf_ex),
             self.wf_ex.context,
             self.wf_ex.input
         )
@@ -459,29 +460,33 @@ class RegularTask(Task):
         )
 
     def _evaluate_expression(self, expression, ctx=None):
+        ctx = ctx or self.ctx
         ctx_view = data_flow.ContextView(
-            data_flow.get_current_task_dict(self.task_ex),
-            data_flow.get_workflow_environment_dict(self.wf_ex),
-            ctx or self.ctx,
+            ctx,
             self.wf_ex.context,
             self.wf_ex.input
         )
-
-        return expr.evaluate_recursively(
+        input_dict = expr.evaluate_recursively(
             expression,
             ctx_view
         )
+        return input_dict
 
     def _build_action(self):
         action_name = self.task_spec.get_action_name()
         wf_name = self.task_spec.get_workflow_name()
 
+        # For dynamic workflow evaluation we regenerate the action.
         if wf_name:
             return actions.WorkflowAction(
                 wf_name=self._evaluate_expression(wf_name),
                 task_ex=self.task_ex
             )
 
+        # For dynamic action evaluation we just regenerate the name.
+        if action_name:
+            action_name = self._evaluate_expression(action_name)
+
         if not action_name:
             action_name = 'std.noop'
 
@@ -498,6 +503,22 @@ class RegularTask(Task):
 
         return actions.PythonAction(action_def, task_ex=self.task_ex)
 
+    def _get_timeout(self):
+        timeout = self.task_spec.get_policies().get_timeout()
+
+        if not isinstance(timeout, (int, float)):
+            wf_ex = self.task_ex.workflow_execution
+
+            ctx_view = data_flow.ContextView(
+                self.task_ex.in_context,
+                wf_ex.context,
+                wf_ex.input
+            )
+
+            timeout = expr.evaluate_recursively(data=timeout, context=ctx_view)
+
+        return timeout if timeout > 0 else None
+
 
 class WithItemsTask(RegularTask):
     """With-items task.
@@ -584,7 +605,8 @@ class WithItemsTask(RegularTask):
                 input_dict,
                 target,
                 index=i,
-                safe_rerun=self.task_spec.get_safe_rerun()
+                safe_rerun=self.task_spec.get_safe_rerun(),
+                timeout=self._get_timeout()
             )
 
             self._decrease_capacity(1)
