@@ -37,7 +37,8 @@ _CHECK_AND_COMPLETE_PATH = (
 
 
 @profiler.trace('workflow-handler-start-workflow', hide_args=True)
-def start_workflow(wf_identifier, wf_namespace, wf_input, desc, params):
+def start_workflow(wf_identifier, wf_namespace, wf_ex_id, wf_input, desc,
+                   params):
     wf = workflows.Workflow()
 
     wf_def = db_api.get_workflow_definition(wf_identifier, wf_namespace)
@@ -47,6 +48,7 @@ def start_workflow(wf_identifier, wf_namespace, wf_input, desc, params):
 
     wf.start(
         wf_def=wf_def,
+        wf_ex_id=wf_ex_id,
         input_dict=wf_input,
         desc=desc,
         params=params
@@ -86,7 +88,7 @@ def cancel_workflow(wf_ex, msg=None):
     stop_workflow(wf_ex, states.CANCELLED, msg)
 
 
-@db_utils.retry_on_deadlock
+@db_utils.retry_on_db_error
 @action_queue.process
 @profiler.trace('workflow-handler-check-and-complete', hide_args=True)
 def _check_and_complete(wf_ex_id):
@@ -174,18 +176,29 @@ def check_and_fix_integrity(wf_ex):
         )
 
         if all_finished:
-            # We found a task execution in RUNNING state for which all
-            # child executions are finished. We need to call
-            # "schedule_on_action_complete" on the task handler for any of
-            # the child executions so that the task state is calculated and
-            # updated properly.
-            LOG.warning(
-                "Found a task execution that is likely stuck in RUNNING state"
-                " because all child executions are finished,"
-                " will try to recover [task_execution=%s]", t_ex.id
+            # Find the timestamp of the most recently finished child.
+            most_recent_child_timestamp = max(
+                [c_ex.updated_at or c_ex.created_at for c_ex in
+                 child_executions]
+            )
+            interval = timeutils.delta_seconds(
+                most_recent_child_timestamp,
+                timeutils.utcnow()
             )
 
-            task_handler.schedule_on_action_complete(child_executions[-1])
+            if interval > check_after_seconds:
+                # We found a task execution in RUNNING state for which all
+                # child executions are finished. We need to call
+                # "schedule_on_action_complete" on the task handler for any of
+                # the child executions so that the task state is calculated and
+                # updated properly.
+                LOG.warning(
+                    "Found a task execution that is likely stuck in RUNNING"
+                    " state because all child executions are finished,"
+                    " will try to recover [task_execution=%s]", t_ex.id
+                )
+
+                task_handler.schedule_on_action_complete(child_executions[-1])
 
 
 def pause_workflow(wf_ex, msg=None):
