@@ -25,7 +25,6 @@ from mistral.engine import action_queue
 from mistral.engine import dispatcher
 from mistral.engine import utils as engine_utils
 from mistral import exceptions as exc
-from mistral import expressions as expr
 from mistral.lang import parser as spec_parser
 from mistral.services import triggers
 from mistral.services import workflows as wf_service
@@ -63,13 +62,16 @@ class Workflow(object):
             self.wf_spec = None
 
     @profiler.trace('workflow-start')
-    def start(self, wf_def, input_dict, desc='', params=None):
+    def start(self, wf_def, wf_ex_id, input_dict, desc='', params=None):
         """Start workflow.
 
         :param wf_def: Workflow definition.
+        :param wf_ex_id: Workflow execution id.
         :param input_dict: Workflow input.
         :param desc: Workflow execution description.
         :param params: Workflow type specific parameters.
+
+        :raises
         """
 
         assert not self.wf_ex
@@ -90,6 +92,7 @@ class Workflow(object):
 
         self._create_execution(
             wf_def,
+            wf_ex_id,
             self.prepare_input(input_dict),
             desc,
             params
@@ -239,12 +242,10 @@ class Workflow(object):
         return db_api.acquire_lock(db_models.WorkflowExecution, self.wf_ex.id)
 
     def _get_final_context(self):
-        final_ctx = {}
-
         wf_ctrl = wf_base.get_controller(self.wf_ex)
-
+        final_context = {}
         try:
-            final_ctx = wf_ctrl.evaluate_workflow_final_context()
+            final_context = wf_ctrl.evaluate_workflow_final_context()
         except Exception as e:
             LOG.warning(
                 'Failed to get final context for workflow execution. '
@@ -254,10 +255,11 @@ class Workflow(object):
                 str(e)
             )
 
-        return final_ctx
+        return final_context
 
-    def _create_execution(self, wf_def, input_dict, desc, params):
+    def _create_execution(self, wf_def, wf_ex_id, input_dict, desc, params):
         self.wf_ex = db_api.create_workflow_execution({
+            'id': wf_ex_id,
             'name': wf_def.name,
             'description': desc,
             'workflow_name': wf_def.name,
@@ -275,12 +277,16 @@ class Workflow(object):
 
         self.wf_ex.input = input_dict or {}
 
-        params['env'] = _get_environment(params)
+        env = _get_environment(params)
+
+        if env:
+            params['env'] = env
 
         self.wf_ex.params = params
 
         data_flow.add_openstack_data_to_context(self.wf_ex)
         data_flow.add_execution_to_context(self.wf_ex)
+        data_flow.add_environment_to_context(self.wf_ex)
         data_flow.add_workflow_variables_to_context(self.wf_ex, self.wf_spec)
 
         spec_parser.cache_workflow_spec_by_execution_id(
@@ -369,16 +375,6 @@ class Workflow(object):
         if incomplete_tasks_count > 0:
             return incomplete_tasks_count
 
-        LOG.debug("Workflow completed [id=%s]", self.wf_ex.id)
-
-        # NOTE(rakhmerov): Once we know that the workflow has completed,
-        # we need to expire all the objects in the DB session to make sure
-        # to read the most relevant data from the DB (that's already been
-        # committed in parallel transactions). Otherwise, some data like
-        # workflow context may be stale and decisions made upon it will be
-        # wrong.
-        db_api.expire_all()
-
         wf_ctrl = wf_base.get_controller(self.wf_ex, self.wf_spec)
 
         if wf_ctrl.any_cancels():
@@ -434,10 +430,21 @@ class Workflow(object):
 
         # When we set an ERROR state we should safely set output value getting
         # w/o exceptions due to field size limitations.
-        msg = utils.cut_by_kb(
-            msg,
-            cfg.CONF.engine.execution_field_size_limit_kb
-        )
+
+        length_output_on_error = len(str(output_on_error).encode("utf-8"))
+        total_output_length = utils.get_number_of_chars_from_kilobytes(
+            cfg.CONF.engine.execution_field_size_limit_kb)
+
+        if length_output_on_error < total_output_length:
+            msg = utils.cut_by_char(
+                msg,
+                total_output_length - length_output_on_error
+            )
+        else:
+            msg = utils.cut_by_kb(
+                msg,
+                cfg.CONF.engine.execution_field_size_limit_kb
+            )
 
         self.wf_ex.output = merge_dicts({'result': msg}, output_on_error)
 
@@ -495,12 +502,10 @@ class Workflow(object):
 def _get_environment(params):
     env = params.get('env', {})
 
-    if not env:
-        return {}
-
     if isinstance(env, dict):
-        env_dict = env
-    elif isinstance(env, six.string_types):
+        return env
+
+    if isinstance(env, six.string_types):
         env_db = db_api.load_environment(env)
 
         if not env_db:
@@ -508,18 +513,12 @@ def _get_environment(params):
                 'Environment is not found: %s' % env
             )
 
-        env_dict = env_db.variables
-    else:
-        raise exc.InputException(
-            'Unexpected value type for environment [env=%s, type=%s]'
-            % (env, type(env))
-        )
+        return env_db.variables
 
-    if ('evaluate_env' in params and
-            not params['evaluate_env']):
-        return env_dict
-    else:
-        return expr.evaluate_recursively(env_dict, {'__env': env_dict})
+    raise exc.InputException(
+        'Unexpected value type for environment [env=%s, type=%s]'
+        % (env, type(env))
+    )
 
 
 def _build_fail_info_message(wf_ctrl, wf_ex):
