@@ -13,11 +13,11 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+from eventlet import timeout as ev_timeout
+from mistral_lib import actions as mistral_lib
 from oslo_log import log as logging
 from osprofiler import profiler
 
-from mistral_lib import actions as mistral_lib
-
 from mistral.actions import action_factory as a_f
 from mistral import context
 from mistral import exceptions as exc
@@ -35,8 +35,8 @@ class DefaultExecutor(base.Executor):
 
     @profiler.trace('default-executor-run-action', hide_args=True)
     def run_action(self, action_ex_id, action_cls_str, action_cls_attrs,
-                   params, safe_rerun, redelivered=False,
-                   target=None, async_=True):
+                   params, safe_rerun, execution_context, redelivered=False,
+                   target=None, async_=True, timeout=None):
         """Runs action.
 
         :param action_ex_id: Action execution id.
@@ -45,11 +45,15 @@ class DefaultExecutor(base.Executor):
             will be set to.
         :param params: Action parameters.
         :param safe_rerun: Tells if given action can be safely rerun.
+        :param execution_context: A dict of values providing information about
+            the current execution.
         :param redelivered: Tells if given action was run before on another
             executor.
         :param target: Target (group of action executors).
         :param async_: If True, run action in asynchronous mode (w/o waiting
             for completion).
+        :param timeout: a period of time in seconds after which execution of
+            action will be interrupted
         :return: Action result.
         """
 
@@ -101,14 +105,15 @@ class DefaultExecutor(base.Executor):
 
         # Run action.
         try:
-
-            # NOTE(d0ugal): If the action is a subclass of mistral-lib we know
-            # that it expects to be passed the context. We should deprecate
-            # the builtin action class in Mistral.
-            if isinstance(action, mistral_lib.Action):
-                result = action.run(context.ctx())
-            else:
-                result = action.run()
+            with ev_timeout.Timeout(seconds=timeout):
+                # NOTE(d0ugal): If the action is a subclass of mistral-lib we
+                # know that it expects to be passed the context.
+                if isinstance(action, mistral_lib.Action):
+                    action_ctx = context.create_action_context(
+                        execution_context)
+                    result = action.run(action_ctx)
+                else:
+                    result = action.run()
 
             # Note: it's made for backwards compatibility with already
             # existing Mistral actions which don't return result as
@@ -116,7 +121,7 @@ class DefaultExecutor(base.Executor):
             if not isinstance(result, mistral_lib.Result):
                 result = mistral_lib.Result(data=result)
 
-        except Exception as e:
+        except BaseException as e:
             msg = (
                 "Failed to run action [action_ex_id=%s, action_cls='%s', "
                 "attributes='%s', params='%s']\n %s" % (
