@@ -51,8 +51,6 @@ def cleanup():
     _EXECUTOR_CLIENT = None
     _EVENT_ENGINE_CLIENT = None
 
-    base.cleanup()
-
 
 def get_engine_client():
     global _ENGINE_CLIENT
@@ -98,18 +96,27 @@ class EngineClient(eng.Engine):
         self._client = base.get_rpc_client_driver()(rpc_conf_dict)
 
     @base.wrap_messaging_exception
-    def start_workflow(self, wf_identifier, wf_namespace, wf_input=None,
-                       description='', **params):
+    def start_workflow(self, wf_identifier, wf_namespace='', wf_ex_id=None,
+                       wf_input=None, description='', **params):
         """Starts workflow sending a request to engine over RPC.
 
+        :param wf_identifier: Workflow identifier.
+        :param wf_namespace Workflow namespace.
+        :param wf_namespace: Workflow namespace.
+        :param wf_input: Workflow input data as a dictionary.
+        :param wf_ex_id: Workflow execution id. If passed, it will be set
+            in the new execution object.
+        :param description: Execution description.
+        :param params: Additional workflow type specific parameters.
         :return: Workflow execution.
         """
         return self._client.sync_call(
             auth_ctx.ctx(),
             'start_workflow',
-            workflow_identifier=wf_identifier,
-            workflow_namespace=wf_namespace,
-            workflow_input=wf_input or {},
+            wf_identifier=wf_identifier,
+            wf_namespace=wf_namespace,
+            wf_ex_id=wf_ex_id,
+            wf_input=wf_input or {},
             description=description,
             params=params
         )
@@ -119,6 +126,10 @@ class EngineClient(eng.Engine):
                      description=None, **params):
         """Starts action sending a request to engine over RPC.
 
+        :param action_name: Action name.
+        :param action_input: Action input data as a dictionary.
+        :param description: Execution description.
+        :param params: Additional options for action running.
         :return: Action execution.
         """
         return self._client.sync_call(
@@ -151,7 +162,7 @@ class EngineClient(eng.Engine):
             a workflow execution rather than action execution. It happens
             when a nested workflow execution sends its result to a parent
             workflow.
-        :param async: If True, run action in asynchronous mode (w/o waiting
+        :param async_: If True, run action in asynchronous mode (w/o waiting
             for completion).
         :return: Action(or workflow if wf_action=True) execution object.
         """
@@ -185,7 +196,7 @@ class EngineClient(eng.Engine):
             a workflow execution rather than action execution. It happens
             when a nested workflow execution sends its result to a parent
             workflow.
-        :param async: If True, run action in asynchronous mode (w/o waiting
+        :param async_: If True, run action in asynchronous mode (w/o waiting
             for completion).
         :return: Action(or workflow if wf_action=True) execution object.
         """
@@ -211,7 +222,7 @@ class EngineClient(eng.Engine):
         return self._client.sync_call(
             auth_ctx.ctx(),
             'pause_workflow',
-            execution_id=wf_ex_id
+            wf_ex_id=wf_ex_id
         )
 
     @base.wrap_messaging_exception
@@ -269,7 +280,7 @@ class EngineClient(eng.Engine):
         return self._client.sync_call(
             auth_ctx.ctx(),
             'stop_workflow',
-            execution_id=wf_ex_id,
+            wf_ex_id=wf_ex_id,
             state=state,
             message=message
         )
@@ -286,7 +297,7 @@ class EngineClient(eng.Engine):
         return self._client.sync_call(
             auth_ctx.ctx(),
             'rollback_workflow',
-            execution_id=wf_ex_id
+            wf_ex_id=wf_ex_id
         )
 
 
@@ -301,8 +312,8 @@ class ExecutorClient(exe.Executor):
 
     @profiler.trace('executor-client-run-action')
     def run_action(self, action_ex_id, action_cls_str, action_cls_attrs,
-                   params, safe_rerun, redelivered=False,
-                   target=None, async_=True):
+                   params, safe_rerun, execution_context, redelivered=False,
+                   target=None, async_=True, timeout=None):
         """Sends a request to run action to executor.
 
         :param action_ex_id: Action execution id.
@@ -311,11 +322,15 @@ class ExecutorClient(exe.Executor):
         :param params: Action input parameters.
         :param safe_rerun: If true, action would be re-run if executor dies
             during execution.
+        :param execution_context: A dict of values providing information about
+            the current execution.
         :param redelivered: Tells if given action was run before on another
             executor.
         :param target: Target (group of action executors).
         :param async_: If True, run action in asynchronous mode (w/o waiting
             for completion).
+        :param timeout: a period of time in seconds after which execution of
+            action will be interrupted
         :return: Action result.
         """
 
@@ -324,7 +339,9 @@ class ExecutorClient(exe.Executor):
             'action_cls_str': action_cls_str,
             'action_cls_attrs': action_cls_attrs,
             'params': params,
-            'safe_rerun': safe_rerun
+            'safe_rerun': safe_rerun,
+            'execution_context': execution_context,
+            'timeout': timeout
         }
 
         rpc_client_method = (self._client.async_call
