@@ -109,19 +109,6 @@ class OpenStackActionTest(base.BaseTestCase):
         self.assertTrue(mocked().volumes.get.called)
         mocked().volumes.get.assert_called_once_with(volume="1234-abcd")
 
-    @mock.patch.object(actions.CeilometerAction, '_get_client')
-    def test_ceilometer_action(self, mocked):
-        mock_ctx = mock.Mock()
-        method_name = "alarms.get"
-        action_class = actions.CeilometerAction
-        action_class.client_method_name = method_name
-        params = {'alarm_id': '1234-abcd'}
-        action = action_class(**params)
-        action.run(mock_ctx)
-
-        self.assertTrue(mocked().alarms.get.called)
-        mocked().alarms.get.assert_called_once_with(alarm_id="1234-abcd")
-
     @mock.patch.object(actions.TroveAction, '_get_client')
     def test_trove_action(self, mocked):
         mock_ctx = mock.Mock()
