@@ -39,7 +39,7 @@ WF = models.WorkflowDefinition(
 WF.update({'id': '123e4567-e89b-12d3-a456-426655440000', 'name': 'my_wf'})
 
 TRIGGER = {
-    'id': '123',
+    'id': '02abb422-55ef-4bb2-8cb9-217a583a6a3f',
     'name': 'my_cron_trigger',
     'pattern': '* * * * *',
     'workflow_name': WF.name,
@@ -59,6 +59,8 @@ trigger_values['workflow_params'] = json.loads(
 
 TRIGGER_DB = models.CronTrigger()
 TRIGGER_DB.update(trigger_values)
+TRIGGER_DB_WITH_PROJECT_ID = TRIGGER_DB.get_clone()
+TRIGGER_DB_WITH_PROJECT_ID.project_id = '<default-project>'
 
 MOCK_WF = mock.MagicMock(return_value=WF)
 MOCK_TRIGGER = mock.MagicMock(return_value=TRIGGER_DB)
@@ -90,6 +92,14 @@ class TestCronTriggerController(base.APITest):
         self.assertEqual(200, resp.status_int)
         self.assertDictEqual(TRIGGER, resp.json)
 
+    @mock.patch.object(db_api, "get_cron_trigger",
+                       return_value=TRIGGER_DB_WITH_PROJECT_ID)
+    def test_get_within_project_id(self, mock_get):
+        resp = self.app.get('/v2/cron_triggers/my_cron_trigger')
+
+        self.assertEqual(200, resp.status_int)
+        self.assertTrue('project_id' in resp.json)
+
     @mock.patch.object(db_api, "get_cron_trigger", MOCK_NOT_FOUND)
     def test_get_not_found(self):
         resp = self.app.get(
@@ -99,6 +109,13 @@ class TestCronTriggerController(base.APITest):
 
         self.assertEqual(404, resp.status_int)
 
+    @mock.patch.object(db_api, "get_cron_trigger", MOCK_TRIGGER)
+    def test_get_by_id(self):
+        resp = self.app.get(
+            "/v2/cron_triggers/02abb422-55ef-4bb2-8cb9-217a583a6a3f")
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(TRIGGER, resp.json)
+
     @mock.patch.object(db_api, "get_workflow_definition", MOCK_WF)
     @mock.patch.object(db_api, "create_cron_trigger")
     def test_post(self, mock_mtd):
@@ -148,6 +165,16 @@ class TestCronTriggerController(base.APITest):
         self.assertEqual(1, delete_trust.call_count)
         self.assertEqual(204, resp.status_int)
 
+    @mock.patch.object(db_api, "get_cron_trigger", MOCK_TRIGGER)
+    @mock.patch.object(db_api, "delete_cron_trigger", MOCK_DELETE)
+    @mock.patch.object(security, "delete_trust")
+    def test_delete_by_id(self, delete_trust):
+        resp = self.app.delete(
+            '/v2/cron_triggers/02abb422-55ef-4bb2-8cb9-217a583a6a3f')
+
+        self.assertEqual(1, delete_trust.call_count)
+        self.assertEqual(204, resp.status_int)
+
     @mock.patch.object(db_api, "delete_cron_trigger", MOCK_NOT_FOUND)
     def test_delete_not_found(self):
         resp = self.app.delete(
@@ -193,6 +220,25 @@ class TestCronTriggerController(base.APITest):
 
         self.assertTrue(mock_get_triggers.call_args[1].get('insecure', False))
 
+    @mock.patch.object(db_api, 'get_cron_triggers')
+    @mock.patch('mistral.context.MistralContext.from_environ')
+    def test_get_all_filter_project(self, mock_context, mock_get_triggers):
+        admin_ctx = unit_base.get_context(admin=True)
+        mock_context.return_value = admin_ctx
+
+        resp = self.app.get(
+            '/v2/cron_triggers?all_projects=true&'
+            'project_id=192796e61c174f718d6147b129f3f2ff'
+        )
+
+        self.assertEqual(200, resp.status_int)
+
+        self.assertTrue(mock_get_triggers.call_args[1].get('insecure', False))
+        self.assertEqual(
+            {'eq': '192796e61c174f718d6147b129f3f2ff'},
+            mock_get_triggers.call_args[1].get('project_id')
+        )
+
     @mock.patch.object(db_api, "get_cron_triggers", MOCK_EMPTY)
     def test_get_all_empty(self):
         resp = self.app.get('/v2/cron_triggers')
