@@ -122,9 +122,20 @@ UPDATED_WF_EX_ENV_DESC['params'] = {'env': {'k1': 'def'}}
 
 WF_EX_JSON_WITH_DESC = copy.deepcopy(WF_EX_JSON)
 WF_EX_JSON_WITH_DESC['description'] = WF_EX.description
+WF_EX_WITH_PROJECT_ID = WF_EX.get_clone()
+WF_EX_WITH_PROJECT_ID.project_id = '<default-project>'
+
+SOURCE_WF_EX = copy.deepcopy(WF_EX)
+SOURCE_WF_EX['source_execution_id'] = WF_EX.id
+SOURCE_WF_EX['id'] = uuidutils.generate_uuid()
+SOURCE_WF_EX_JSON_WITH_DESC = copy.deepcopy(WF_EX_JSON_WITH_DESC)
+SOURCE_WF_EX_JSON_WITH_DESC['id'] = SOURCE_WF_EX.id
+SOURCE_WF_EX_JSON_WITH_DESC['source_execution_id'] = \
+    SOURCE_WF_EX.source_execution_id
 
 MOCK_WF_EX = mock.MagicMock(return_value=WF_EX)
 MOCK_SUB_WF_EX = mock.MagicMock(return_value=SUB_WF_EX)
+MOCK_SOURCE_WF_EX = mock.MagicMock(return_value=SOURCE_WF_EX)
 MOCK_WF_EXECUTIONS = mock.MagicMock(return_value=[WF_EX])
 MOCK_UPDATED_WF_EX = mock.MagicMock(return_value=UPDATED_WF_EX)
 MOCK_DELETE = mock.MagicMock(return_value=None)
@@ -168,9 +179,16 @@ class TestExecutionsController(base.APITest):
 
         self.assertEqual(404, resp.status_int)
 
+    @mock.patch.object(db_api, 'get_workflow_execution',
+                       return_value=WF_EX_WITH_PROJECT_ID)
+    def test_get_within_project_id(self, mock_get):
+        resp = self.app.get('/v2/executions/123', expect_errors=True)
+        self.assertEqual(200, resp.status_int)
+        self.assertTrue('project_id' in resp.json)
+
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     @mock.patch.object(
@@ -194,7 +212,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     @mock.patch.object(rpc_clients.EngineClient, 'stop_workflow')
@@ -222,7 +240,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     @mock.patch.object(rpc_clients.EngineClient, 'stop_workflow')
@@ -255,7 +273,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     @mock.patch.object(rpc_clients.EngineClient, 'resume_workflow')
@@ -282,7 +300,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     def test_put_invalid_state(self):
@@ -309,7 +327,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     @mock.patch.object(rpc_clients.EngineClient, 'stop_workflow')
@@ -334,7 +352,7 @@ class TestExecutionsController(base.APITest):
         self.assertDictEqual(expected_exec, resp.json)
         mock_stop_wf.assert_called_once_with('123', 'ERROR', None)
 
-    @mock.patch('mistral.db.v2.api.ensure_workflow_execution_exists')
+    @mock.patch('mistral.db.v2.api.get_workflow_execution')
     @mock.patch(
         'mistral.db.v2.api.update_workflow_execution',
         return_value=WF_EX
@@ -379,7 +397,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     def test_put_empty(self):
@@ -393,7 +411,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     def test_put_state_and_description(self):
@@ -409,11 +427,6 @@ class TestExecutionsController(base.APITest):
             resp.json['faultstring']
         )
 
-    @mock.patch.object(
-        db_api,
-        'ensure_workflow_execution_exists',
-        mock.MagicMock(return_value=None)
-    )
     @mock.patch.object(
         sql_db_api,
         'get_workflow_execution',
@@ -444,7 +457,7 @@ class TestExecutionsController(base.APITest):
 
     @mock.patch.object(
         db_api,
-        'ensure_workflow_execution_exists',
+        'get_workflow_execution',
         mock.MagicMock(return_value=None)
     )
     def test_put_env_wrong_state(self):
@@ -470,19 +483,181 @@ class TestExecutionsController(base.APITest):
         self.assertIn(expected_fault, resp.json['faultstring'])
 
     @mock.patch.object(rpc_clients.EngineClient, 'start_workflow')
-    def test_post(self, f):
-        f.return_value = WF_EX.to_dict()
+    @mock.patch.object(db_api, 'load_workflow_execution')
+    def test_post_auto_id(self, load_wf_ex_func, start_wf_func):
+        # NOTE: In fact, we use "white box" testing here to understand
+        # if the REST controller calls other APIs as expected. This is
+        # the only way of testing available with the current testing
+        # infrastructure.
+        start_wf_func.return_value = WF_EX.to_dict()
 
-        resp = self.app.post_json('/v2/executions', WF_EX_JSON_WITH_DESC)
+        json_body = WF_EX_JSON_WITH_DESC.copy()
+
+        # We don't want to pass execution ID in this case.
+        del json_body['id']
+
+        expected_json = WF_EX_JSON_WITH_DESC
+
+        resp = self.app.post_json('/v2/executions', json_body)
 
         self.assertEqual(201, resp.status_int)
-        self.assertDictEqual(WF_EX_JSON_WITH_DESC, resp.json)
+        self.assertDictEqual(expected_json, resp.json)
 
-        exec_dict = WF_EX_JSON_WITH_DESC
+        load_wf_ex_func.assert_not_called()
 
-        f.assert_called_once_with(
+        start_wf_func.assert_called_once_with(
+            expected_json['workflow_id'],
+            '',
+            None,
+            json.loads(expected_json['input']),
+            expected_json['description'],
+            **json.loads(expected_json['params'])
+        )
+
+    @mock.patch.object(rpc_clients.EngineClient, 'start_workflow')
+    @mock.patch.object(db_api, 'load_workflow_execution')
+    def test_post_with_exec_id_exec_doesnt_exist(self, load_wf_ex_func,
+                                                 start_wf_func):
+        # NOTE: In fact, we use "white box" testing here to understand
+        # if the REST controller calls other APIs as expected. This is
+        # the only way of testing available with the current testing
+        # infrastructure.
+
+        # Imitate that the execution doesn't exist in DB.
+        load_wf_ex_func.return_value = None
+        start_wf_func.return_value = WF_EX.to_dict()
+
+        # We want to pass execution ID in this case so we don't delete 'id'
+        # from the dict.
+        json_body = WF_EX_JSON_WITH_DESC.copy()
+
+        expected_json = WF_EX_JSON_WITH_DESC
+
+        resp = self.app.post_json('/v2/executions', json_body)
+
+        self.assertEqual(201, resp.status_int)
+        self.assertDictEqual(expected_json, resp.json)
+
+        load_wf_ex_func.assert_called_once_with(expected_json['id'])
+
+        start_wf_func.assert_called_once_with(
+            expected_json['workflow_id'],
+            '',
+            expected_json['id'],
+            json.loads(expected_json['input']),
+            expected_json['description'],
+            **json.loads(expected_json['params'])
+        )
+
+    @mock.patch.object(rpc_clients.EngineClient, 'start_workflow')
+    @mock.patch.object(db_api, 'load_workflow_execution')
+    def test_post_with_exec_id_exec_exists(self, load_wf_ex_func,
+                                           start_wf_func):
+        # NOTE: In fact, we use "white box" testing here to understand
+        # if the REST controller calls other APIs as expected. This is
+        # the only way of testing available with the current testing
+        # infrastructure.
+
+        # Imitate that the execution exists in DB.
+        load_wf_ex_func.return_value = WF_EX
+
+        # We want to pass execution ID in this case so we don't delete 'id'
+        # from the dict.
+        json_body = WF_EX_JSON_WITH_DESC.copy()
+
+        expected_json = WF_EX_JSON_WITH_DESC
+
+        resp = self.app.post_json('/v2/executions', json_body)
+
+        self.assertEqual(201, resp.status_int)
+        self.assertDictEqual(expected_json, resp.json)
+
+        load_wf_ex_func.assert_called_once_with(expected_json['id'])
+
+        # Note that "start_workflow" method on engine API should not be called
+        # in this case because we passed execution ID to the endpoint and the
+        # corresponding object exists.
+        start_wf_func.assert_not_called()
+
+    @mock.patch.object(db_api, 'get_workflow_execution', MOCK_WF_EX)
+    @mock.patch.object(rpc_clients.EngineClient, 'start_workflow')
+    def test_post_with_source_execution_id(self, wf_exec_mock):
+        wf_exec_mock.return_value = SOURCE_WF_EX.to_dict()
+
+        resp = self.app.post_json('/v2/executions/',
+                                  SOURCE_WF_EX_JSON_WITH_DESC)
+
+        source_wf_ex_json = copy.copy(SOURCE_WF_EX_JSON_WITH_DESC)
+        del source_wf_ex_json['source_execution_id']
+
+        self.assertEqual(201, resp.status_int)
+        self.assertDictEqual(source_wf_ex_json, resp.json)
+
+        exec_dict = source_wf_ex_json
+
+        wf_exec_mock.assert_called_once_with(
             exec_dict['workflow_id'],
             '',
+            exec_dict['id'],
+            json.loads(exec_dict['input']),
+            exec_dict['description'],
+            **json.loads(exec_dict['params'])
+        )
+
+    @mock.patch.object(db_api, 'get_workflow_execution', MOCK_WF_EX)
+    @mock.patch.object(rpc_clients.EngineClient, 'start_workflow')
+    def test_post_with_src_exec_id_without_exec_id(self, wf_exec_mock):
+        source_wf_ex = copy.copy(SOURCE_WF_EX)
+        source_wf_ex.id = ""
+
+        source_wf_ex_json = copy.copy(SOURCE_WF_EX_JSON_WITH_DESC)
+        source_wf_ex_json['id'] = ''
+
+        wf_exec_mock.return_value = source_wf_ex.to_dict()
+
+        resp = self.app.post_json('/v2/executions/', source_wf_ex_json)
+
+        del source_wf_ex_json['source_execution_id']
+
+        self.assertEqual(201, resp.status_int)
+        self.assertDictEqual(source_wf_ex_json, resp.json)
+
+        exec_dict = source_wf_ex_json
+
+        wf_exec_mock.assert_called_once_with(
+            exec_dict['workflow_id'],
+            '',
+            '',
+            json.loads(exec_dict['input']),
+            exec_dict['description'],
+            **json.loads(exec_dict['params'])
+        )
+
+    @mock.patch.object(db_api, 'get_workflow_execution', MOCK_EMPTY)
+    @mock.patch.object(rpc_clients.EngineClient, 'start_workflow')
+    def test_post_without_source_execution_id(self, wf_exec_mock):
+        wf_exec_mock.return_value = SOURCE_WF_EX.to_dict()
+
+        source_wf_ex_json = copy.copy(SOURCE_WF_EX_JSON_WITH_DESC)
+        source_wf_ex_json['source_execution_id'] = ""
+        # here we want to pass an empty value into the api for the
+        # source execution id to make sure that the correct actions are
+        # taken.
+
+        resp = self.app.post_json('/v2/executions/', source_wf_ex_json)
+        self.assertEqual(201, resp.status_int)
+
+        del source_wf_ex_json['source_execution_id']
+        # here we have to remove the source execution key as the
+        # id is only used to perform a lookup.
+
+        self.assertDictEqual(source_wf_ex_json, resp.json)
+        exec_dict = source_wf_ex_json
+
+        wf_exec_mock.assert_called_once_with(
+            exec_dict['workflow_id'],
+            '',
+            exec_dict['id'],
             json.loads(exec_dict['input']),
             exec_dict['description'],
             **json.loads(exec_dict['params'])
@@ -653,7 +828,10 @@ class TestExecutionsController(base.APITest):
         args, kwargs = mock_get_all.call_args
         resource_function = kwargs['resource_function']
 
-        self.assertEqual(execution._get_execution_resource, resource_function)
+        self.assertEqual(
+            execution._get_workflow_execution_resource,
+            resource_function
+        )
 
     @mock.patch.object(db_api, 'get_workflow_executions', MOCK_WF_EXECUTIONS)
     @mock.patch.object(rest_utils, 'get_all')
