@@ -182,7 +182,7 @@ class BaseTest(base.BaseTestCase):
 
         self.fail(self._formatMessage(msg, standardMsg))
 
-    def _await(self, predicate, delay=1, timeout=60):
+    def _await(self, predicate, delay=1, timeout=60, fail_message="no detail"):
         """Awaits for predicate function to evaluate to True.
 
         If within a configured timeout predicate function hasn't evaluated
@@ -191,6 +191,7 @@ class BaseTest(base.BaseTestCase):
         :param delay: Delay in seconds between predicate function calls.
         :param timeout: Maximum amount of time to wait for predication
             function to evaluate to True.
+        :param fail_message: explains what was expected
         :return:
         """
         end_time = time.time() + timeout
@@ -200,7 +201,9 @@ class BaseTest(base.BaseTestCase):
                 break
 
             if time.time() + delay > end_time:
-                raise AssertionError("Failed to wait for expected result.")
+                raise AssertionError(
+                    "Failed to wait for expected result: " + fail_message
+                )
 
             time.sleep(delay)
 
