@@ -145,8 +145,8 @@ class WorkbookTest(SQLAlchemyTest):
         fetched = db_api.get_workbooks()
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_workbooks_by_equal_value(self):
         db_api.create_workbook(WORKBOOKS[0])
@@ -203,8 +203,8 @@ class WorkbookTest(SQLAlchemyTest):
         fetched = db_api.get_workbooks(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_workbooks_by_less_than_value(self):
         created0 = db_api.create_workbook(WORKBOOKS[0])
@@ -232,8 +232,8 @@ class WorkbookTest(SQLAlchemyTest):
         fetched = db_api.get_workbooks(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_workbooks_by_values_in_list(self):
         created0 = db_api.create_workbook(WORKBOOKS[0])
@@ -489,8 +489,8 @@ class WorkflowDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_workflow_definitions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_workflow_definition_by_less_than_value(self):
         created0 = db_api.create_workflow_definition(WF_DEFINITIONS[0])
@@ -518,8 +518,8 @@ class WorkflowDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_workflow_definitions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_workflow_definition_by_values_in_list(self):
         created0 = db_api.create_workflow_definition(WF_DEFINITIONS[0])
@@ -782,8 +782,8 @@ class WorkflowDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_workflow_definitions()
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_delete_workflow_definition(self):
         created0 = db_api.create_workflow_definition(WF_DEFINITIONS[0])
@@ -996,8 +996,8 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_action_definitions_by_greater_than_value(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1012,8 +1012,8 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created1, fetched[0])
-        self.assertEqual(created2, fetched[1])
+        self.assertIn(created1, fetched)
+        self.assertIn(created2, fetched)
 
     def test_filter_action_definitions_by_greater_than_equal_value(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1028,9 +1028,9 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(3, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
-        self.assertEqual(created2, fetched[2])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
+        self._assert_single_item(fetched, name=created2['name'])
 
     def test_filter_action_definitions_by_less_than_value(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1045,8 +1045,8 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_action_definitions_by_less_than_equal_value(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1061,9 +1061,9 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(3, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
-        self.assertEqual(created2, fetched[2])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
+        self._assert_single_item(fetched, name=created2['name'])
 
     def test_filter_action_definitions_by_values_in_list(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1079,8 +1079,8 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_action_definitions_by_values_notin_list(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1095,7 +1095,7 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(**_filter)
 
         self.assertEqual(1, len(fetched))
-        self.assertEqual(created2, fetched[0])
+        self._assert_single_item(fetched, name=created2['name'])
 
     def test_filter_action_definitions_by_multiple_columns(self):
         created0 = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1204,8 +1204,8 @@ class ActionDefinitionTest(SQLAlchemyTest):
         fetched = db_api.get_action_definitions(is_system=True)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_delete_action_definition_with_name(self):
         created = db_api.create_action_definition(ACTION_DEFINITIONS[0])
@@ -1606,8 +1606,8 @@ class WorkflowExecutionTest(SQLAlchemyTest):
             fetched = db_api.get_workflow_executions(**_filter)
 
             self.assertEqual(2, len(fetched))
-            self.assertEqual(created0, fetched[0])
-            self.assertEqual(created1, fetched[1])
+            self._assert_single_item(fetched, state=created0['state'])
+            self._assert_single_item(fetched, state=created1['state'])
 
     def test_filter_workflow_execution_by_less_than_value(self):
         with db_api.transaction():
@@ -1637,8 +1637,8 @@ class WorkflowExecutionTest(SQLAlchemyTest):
             fetched = db_api.get_workflow_executions(**_filter)
 
             self.assertEqual(2, len(fetched))
-            self.assertEqual(created0, fetched[0])
-            self.assertEqual(created1, fetched[1])
+            self._assert_single_item(fetched, state=created0['state'])
+            self._assert_single_item(fetched, state=created1['state'])
 
     def test_filter_workflow_execution_by_values_in_list(self):
         with db_api.transaction():
@@ -1966,8 +1966,8 @@ class TaskExecutionTest(SQLAlchemyTest):
         )
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_task_execution_by_equal_value(self):
         created, _ = self._create_task_executions()
@@ -2020,8 +2020,8 @@ class TaskExecutionTest(SQLAlchemyTest):
         fetched = db_api.get_task_executions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_task_execution_by_less_than_value(self):
         created0, created1 = self._create_task_executions()
@@ -2047,8 +2047,8 @@ class TaskExecutionTest(SQLAlchemyTest):
         fetched = db_api.get_task_executions(**_filter)
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_filter_task_execution_by_values_in_list(self):
         created, _ = self._create_task_executions()
@@ -2190,6 +2190,7 @@ class TaskExecutionTest(SQLAlchemyTest):
 
 CRON_TRIGGERS = [
     {
+        'id': '11111111-1111-1111-1111-111111111111',
         'name': 'trigger1',
         'pattern': '* * * * *',
         'workflow_name': 'my_wf',
@@ -2202,6 +2203,7 @@ CRON_TRIGGERS = [
         'project_id': '<default-project>'
     },
     {
+        'id': '22222222-2222-2222-2222-2222222c2222',
         'name': 'trigger2',
         'pattern': '* * * * *',
         'workflow_name': 'my_wf',
@@ -2286,6 +2288,19 @@ class CronTriggerTest(SQLAlchemyTest):
         self.assertEqual(updated, updated)
         self.assertEqual(0, updated_count)
 
+    def test_update_cron_trigger_by_id(self):
+        created = db_api.create_cron_trigger(CRON_TRIGGERS[0])
+
+        self.assertIsNone(created.updated_at)
+
+        updated, updated_count = db_api.update_cron_trigger(
+            created.id,
+            {'pattern': '*/1 * * * *'}
+        )
+
+        self.assertEqual('*/1 * * * *', updated.pattern)
+        self.assertEqual(1, updated_count)
+
     def test_create_or_update_cron_trigger(self):
         name = 'not-existing-id'
 
@@ -2314,8 +2329,48 @@ class CronTriggerTest(SQLAlchemyTest):
         fetched = db_api.get_cron_triggers(pattern='* * * * *')
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
+
+    def test_get_cron_trigger(self):
+        cron_trigger = db_api.create_cron_trigger(CRON_TRIGGERS[0])
+
+        # Get by id is ok
+        fetched = db_api.get_cron_trigger(cron_trigger.id)
+        self.assertEqual(cron_trigger, fetched)
+
+        # Get by name is ok
+        fetched = db_api.get_cron_trigger(cron_trigger.name)
+        self.assertEqual(cron_trigger, fetched)
+
+    def test_get_cron_trigger_not_found(self):
+        self.assertRaises(
+            exc.DBEntityNotFoundError,
+            db_api.get_cron_trigger,
+            'aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa',
+        )
+
+        self.assertRaises(
+            exc.DBEntityNotFoundError,
+            db_api.get_cron_trigger,
+            'not-exists-cron-trigger',
+        )
+
+    def test_get_cron_trigger_by_id(self):
+        cron_trigger_1 = db_api.create_cron_trigger(CRON_TRIGGERS[0])
+        cron_trigger_2 = db_api.create_cron_trigger(CRON_TRIGGERS[1])
+
+        fetched = db_api.get_cron_trigger_by_id(cron_trigger_1.id)
+        self.assertEqual(cron_trigger_1, fetched)
+
+        fetched = db_api.get_cron_trigger_by_id(cron_trigger_2.id)
+        self.assertEqual(cron_trigger_2, fetched)
+
+        self.assertRaises(
+            exc.DBEntityNotFoundError,
+            db_api.get_cron_trigger_by_id,
+            'aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa',
+        )
 
     def test_get_cron_triggers_other_tenant(self):
         created0 = db_api.create_cron_trigger(CRON_TRIGGERS[0])
@@ -2348,6 +2403,22 @@ class CronTriggerTest(SQLAlchemyTest):
             created.name
         )
 
+    def test_delete_cron_trigger_by_id(self):
+        created = db_api.create_cron_trigger(CRON_TRIGGERS[0])
+
+        fetched = db_api.get_cron_trigger(created.name)
+
+        self.assertEqual(created, fetched)
+
+        rowcount = db_api.delete_cron_trigger(created.id)
+
+        self.assertEqual(1, rowcount)
+        self.assertRaises(
+            exc.DBEntityNotFoundError,
+            db_api.get_cron_trigger,
+            created.id
+        )
+
     def test_cron_trigger_repr(self):
         s = db_api.create_cron_trigger(CRON_TRIGGERS[0]).__repr__()
 
@@ -2460,8 +2531,8 @@ class EnvironmentTest(SQLAlchemyTest):
         fetched = db_api.get_environments()
 
         self.assertEqual(2, len(fetched))
-        self.assertEqual(created0, fetched[0])
-        self.assertEqual(created1, fetched[1])
+        self._assert_single_item(fetched, name=created0['name'])
+        self._assert_single_item(fetched, name=created1['name'])
 
     def test_delete_environment(self):
         created = db_api.create_environment(ENVIRONMENTS[0])
