@@ -55,6 +55,16 @@ actions:
     output:
       nested_concat: '{{ _ }}'
 
+  missing_base:
+    base: wrong
+    input:
+      - some_input
+
+  nested_missing_base:
+    base: missing_base
+    input:
+      - some_input
+
 workflows:
   wf1:
     type: direct
@@ -118,6 +128,32 @@ workflows:
         action: nested_concat
         publish:
           nested_result: '{{ task().result }}'
+
+  wf6:
+    type: direct
+    output:
+      workflow_result: '{{ _.missing_result }}'
+    tasks:
+      missing_action:
+        action: missing_base
+        on-complete:
+          - next_action
+      next_action:
+        publish:
+          missing_result: 'Finished'
+
+  wf7:
+    type: direct
+    output:
+      workflow_result: '{{ _.missing_result }}'
+    tasks:
+      nested_missing_action:
+        action: nested_missing_base
+        on-complete:
+          - next_action
+      next_action:
+        publish:
+          missing_result: 'Finished'
 """
 
 
@@ -130,8 +166,7 @@ class AdhocActionsTest(base.EngineTestCase):
     def test_run_workflow_with_adhoc_action(self):
         wf_ex = self.engine.start_workflow(
             'my_wb.wf1',
-            '',
-            {'str1': 'a', 'str2': 'b'}
+            wf_input={'str1': 'a', 'str2': 'b'}
         )
 
         self.await_workflow_success(wf_ex.id)
@@ -150,8 +185,7 @@ class AdhocActionsTest(base.EngineTestCase):
     def test_run_adhoc_action_without_input_value(self):
         wf_ex = self.engine.start_workflow(
             'my_wb.wf2',
-            '',
-            {'str1': 'a', 'str2': 'b'}
+            wf_input={'str1': 'a', 'str2': 'b'}
         )
 
         self.await_workflow_success(wf_ex.id)
@@ -169,8 +203,7 @@ class AdhocActionsTest(base.EngineTestCase):
     def test_run_adhoc_action_without_sufficient_input_value(self):
         wf_ex = self.engine.start_workflow(
             'my_wb.wf3',
-            '',
-            {'str1': 'a', 'str2': 'b'}
+            wf_input={'str1': 'a', 'str2': 'b'}
         )
 
         self.assertIn("Invalid input", wf_ex.state_info)
@@ -178,9 +211,13 @@ class AdhocActionsTest(base.EngineTestCase):
 
     def test_run_adhoc_action_with_env(self):
         wf_ex = self.engine.start_workflow(
-            'my_wb.wf4', '', {'str1': 'a'}, env={'foo': 'bar'})
+            'my_wb.wf4',
+            wf_input={'str1': 'a'},
+            env={'foo': 'bar'}
+        )
 
         self.await_workflow_success(wf_ex.id)
+
         with db_api.transaction():
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
@@ -192,10 +229,10 @@ class AdhocActionsTest(base.EngineTestCase):
             )
 
     def test_run_nested_adhoc_with_output(self):
-        wf_ex = self.engine.start_workflow(
-            'my_wb.wf5', '')
+        wf_ex = self.engine.start_workflow('my_wb.wf5')
 
         self.await_workflow_success(wf_ex.id)
+
         with db_api.transaction():
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
@@ -205,3 +242,65 @@ class AdhocActionsTest(base.EngineTestCase):
                 },
                 wf_ex.output
             )
+
+    def test_missing_adhoc_action_definition(self):
+        wf_ex = self.engine.start_workflow('my_wb.wf6')
+
+        self.await_workflow_error(wf_ex.id)
+
+        with db_api.transaction():
+            # Note: We need to reread execution to access related tasks.
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            tasks = wf_ex.task_executions
+
+            task1 = self._assert_single_item(tasks, name='missing_action')
+
+        self.assertEqual(states.ERROR, task1.state)
+
+    def test_nested_missing_adhoc_action_definition(self):
+        wf_ex = self.engine.start_workflow('my_wb.wf7')
+
+        self.await_workflow_error(wf_ex.id)
+
+        with db_api.transaction():
+            # Note: We need to reread execution to access related tasks.
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            tasks = wf_ex.task_executions
+
+            task1 = self._assert_single_item(
+                tasks,
+                name='nested_missing_action'
+            )
+
+        self.assertEqual(states.ERROR, task1.state)
+
+    def test_adhoc_async_action(self):
+        wb_text = """---
+        version: '2.0'
+
+        name: my_wb1
+
+        actions:
+          my_action:
+            input:
+              - my_param
+
+            base: std.mistral_http
+            base-input:
+              url: http://google.com/<% $.my_param %>
+              method: GET
+
+        workflows:
+          my_wf:
+            tasks:
+              task1:
+                action: my_action my_param="asdfasdf"
+        """
+
+        wb_service.create_workbook_v2(wb_text)
+
+        wf_ex = self.engine.start_workflow('my_wb1.my_wf')
+
+        self.await_workflow_running(wf_ex.id)
