@@ -224,7 +224,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(SIMPLE_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -326,7 +326,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         }
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {}, env=env)
+        wf_ex = self.engine.start_workflow('wb1.wf1', env=env)
 
         self.await_workflow_error(wf_ex.id)
 
@@ -338,6 +338,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         self.assertIsNotNone(wf_ex.state_info)
         self.assertEqual(3, len(task_execs))
         self.assertDictEqual(env, wf_ex.params['env'])
+        self.assertDictEqual(env, wf_ex.context['__env'])
 
         task_10_ex = self._assert_single_item(task_execs, name='t10')
         task_21_ex = self._assert_single_item(task_execs, name='t21')
@@ -361,6 +362,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         self.assertEqual(states.RUNNING, wf_ex.state)
         self.assertIsNone(wf_ex.state_info)
         self.assertDictEqual(updated_env, wf_ex.params['env'])
+        self.assertDictEqual(updated_env, wf_ex.context['__env'])
 
         # Await t30 success.
         self.await_task_success(task_30_ex.id)
@@ -470,7 +472,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(SIMPLE_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -524,7 +526,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(WITH_ITEMS_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb3.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb3.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -616,7 +618,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(WITH_ITEMS_WORKBOOK_CONCURRENCY)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb3.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb3.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -698,7 +700,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         env = {'var1': 'fee fi fo fum'}
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb3.wf1', '', {}, env=env)
+        wf_ex = self.engine.start_workflow('wb3.wf1', env=env)
 
         self.await_workflow_error(wf_ex.id)
 
@@ -804,7 +806,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(JOIN_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
@@ -903,7 +905,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(JOIN_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         with db_api.transaction():
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
@@ -1055,7 +1057,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(WITH_ITEMS_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb3.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb3.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -1204,7 +1206,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(SUBFLOW_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -1297,7 +1299,7 @@ class DirectWorkflowRerunTest(base.EngineTestCase):
         wb_service.create_workbook_v2(SUBFLOW_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
