@@ -123,7 +123,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
         wf_service.create_workflows(new_wf)
 
         # Start workflow.
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
 
@@ -136,9 +136,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
         e = self.assertRaises(
             exc.SizeLimitExceededException,
             self.engine.start_workflow,
-            'wf',
-            '',
-            {}
+            'wf'
         )
 
         self.assertEqual(
@@ -154,8 +152,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
             exc.SizeLimitExceededException,
             self.engine.start_workflow,
             'wf',
-            '',
-            {'workflow_input': ''.join('A' for _ in range(1024))}
+            wf_input={'workflow_input': ''.join('A' for _ in range(1024))}
         )
 
         self.assertEqual(
@@ -169,7 +166,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
         wf_service.create_workflows(new_wf)
 
         # Start workflow.
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.assertEqual(states.ERROR, wf_ex.state)
         self.assertIn(
@@ -183,8 +180,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
         # Start workflow.
         wf_ex = self.engine.start_workflow(
             'wf',
-            '',
-            {'action_output_length': 1024}
+            wf_input={'action_output_length': 1024}
         )
 
         self.await_workflow_error(wf_ex.id)
@@ -204,7 +200,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
         wf_service.create_workflows(new_wf)
 
         # Start workflow.
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -237,9 +233,6 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
             exc.SizeLimitExceededException,
             self.engine.start_workflow,
             'wf',
-            '',
-            {},
-            '',
             env={'param': long_string}
         )
 
@@ -261,8 +254,7 @@ class ExecutionFieldsSizeLimitTest(base.EngineTestCase):
         # Start workflow.
         wf_ex = self.engine.start_workflow(
             'wf',
-            '',
-            {
+            wf_input={
                 'action_output_length': 80000,
                 'action_output_dict': True,
                 'action_error': True
