@@ -68,15 +68,11 @@ class ReverseWorkflowEngineTest(base.EngineTestCase):
         wb_service.create_workbook_v2(WORKBOOK)
 
     def test_start_task1(self):
-        wf_input = {
-            'param1': 'a',
-            'param2': 'b'
-        }
+        wf_input = {'param1': 'a', 'param2': 'b'}
 
         wf_ex = self.engine.start_workflow(
             'my_wb.wf1',
-            '',
-            wf_input,
+            wf_input=wf_input,
             task_name='task1'
         )
 
@@ -84,11 +80,7 @@ class ReverseWorkflowEngineTest(base.EngineTestCase):
         self.assertIsNotNone(wf_ex)
         self.assertDictEqual(wf_input, wf_ex.input)
         self.assertDictEqual(
-            {
-                'task_name': 'task1',
-                'namespace': '',
-                'env': {}
-            },
+            {'task_name': 'task1', 'namespace': ''},
             wf_ex.params
         )
 
@@ -112,15 +104,11 @@ class ReverseWorkflowEngineTest(base.EngineTestCase):
         self.assertDictEqual({'result1': 'a'}, task_ex.published)
 
     def test_start_task2(self):
-        wf_input = {
-            'param1': 'a',
-            'param2': 'b'
-        }
+        wf_input = {'param1': 'a', 'param2': 'b'}
 
         wf_ex = self.engine.start_workflow(
             'my_wb.wf1',
-            '',
-            wf_input,
+            wf_input=wf_input,
             task_name='task2'
         )
 
@@ -128,11 +116,7 @@ class ReverseWorkflowEngineTest(base.EngineTestCase):
         self.assertIsNotNone(wf_ex)
         self.assertDictEqual(wf_input, wf_ex.input)
         self.assertDictEqual(
-            {
-                'task_name': 'task2',
-                'namespace': '',
-                'env': {}
-            },
+            {'task_name': 'task2', 'namespace': ''},
             wf_ex.params
         )
 
@@ -168,8 +152,7 @@ class ReverseWorkflowEngineTest(base.EngineTestCase):
 
         wf_ex = self.engine.start_workflow(
             'my_wb.wf1',
-            '',
-            wf_input,
+            wf_input=wf_input,
             task_name='task4'
         )
 
