@@ -67,7 +67,7 @@ class TaskPublishTest(base.EngineTestCase):
         wb_service.create_workbook_v2(SIMPLE_WORKBOOK)
 
         # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', '', {})
+        wf_ex = self.engine.start_workflow('wb1.wf1')
 
         self.await_workflow_error(wf_ex.id)
 
