@@ -62,7 +62,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
 
@@ -130,7 +130,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
 
@@ -165,7 +165,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -198,7 +198,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
 
@@ -206,12 +206,10 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
             task1_ex = self._assert_single_item(
-                wf_ex.task_executions,
-                name='task1'
+                wf_ex.task_executions, name='task1'
             )
             task2_ex = self._assert_single_item(
-                wf_ex.task_executions,
-                name='task2'
+                wf_ex.task_executions, name='task2'
             )
 
             self.assertDictEqual(
@@ -231,11 +229,6 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
                 task2_ex.published
             )
 
-        # The internal data needed for evaluation of the task() function
-        # should not be persisted to DB.
-        self.assertNotIn('__task_execution', task1_ex.in_context)
-        self.assertNotIn('__task_execution', task2_ex.in_context)
-
     def test_task_function_no_name_on_complete_case(self):
         wf_text = """---
             version: '2.0'
@@ -250,7 +243,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_error(wf_ex.id)
 
@@ -282,7 +275,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
 
@@ -307,7 +300,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_service.create_workflows(wf_text)
 
-        wf_ex = self.engine.start_workflow('wf', '', {})
+        wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
 
@@ -344,8 +337,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
 
         wf_ex = self.engine.start_workflow(
             'wf',
-            '',
-            {'k1': 'v1'},
+            wf_input={'k1': 'v1'},
             param1='blablabla'
         )
 
@@ -378,11 +370,7 @@ class YAQLFunctionsEngineTest(engine_test_base.EngineTestCase):
         )
 
         self.assertDictEqual(
-            {
-                'param1': 'blablabla',
-                'namespace': '',
-                'env': {}
-            },
+            {'param1': 'blablabla', 'namespace': ''},
             execution['params']
         )
 
