@@ -12,8 +12,10 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+import datetime
 import mock
 
+from mistral.db.v2.sqlalchemy import api as db_api
 from mistral import exceptions as exc
 from mistral.expressions import jinja_expression as expr
 from mistral.tests.unit import base
@@ -36,6 +38,38 @@ SERVERS = {
     ]
 }
 
+WF_EXECS = [
+    {
+        'spec': {},
+        'id': "one",
+        'start_params': {'task': 'my_task1'},
+        'state': 'IDLE',
+        'state_info': "Running...",
+        'created_at': datetime.datetime(2016, 12, 1, 15, 0, 0),
+        'updated_at': None,
+        'context': None,
+        'task_id': None,
+        'trust_id': None,
+        'description': None,
+        'output': None
+    },
+    {
+        'spec': {},
+        'id': "two",
+        'root_execution_id': "one",
+        'start_params': {'task': 'my_task1'},
+        'state': 'RUNNING',
+        'state_info': "Running...",
+        'created_at': datetime.datetime(2016, 12, 1, 15, 1, 0),
+        'updated_at': None,
+        'context': {'image_id': '123123'},
+        'task_id': None,
+        'trust_id': None,
+        'description': None,
+        'output': None
+    }
+]
+
 
 class JinjaEvaluatorTest(base.BaseTest):
     def setUp(self):
@@ -205,7 +239,9 @@ class JinjaEvaluatorTest(base.BaseTest):
             'state': task.state,
             'state_info': task.state_info,
             'type': task.type,
-            'workflow_execution_id': task.workflow_execution_id
+            'workflow_execution_id': task.workflow_execution_id,
+            'created_at': task.created_at.isoformat(' '),
+            'updated_at': task.updated_at.isoformat(' ')
         }, result)
 
     @mock.patch('mistral.db.v2.api.get_task_executions')
@@ -232,7 +268,9 @@ class JinjaEvaluatorTest(base.BaseTest):
             'state': task.state,
             'state_info': task.state_info,
             'type': task.type,
-            'workflow_execution_id': task.workflow_execution_id
+            'workflow_execution_id': task.workflow_execution_id,
+            'created_at': task.created_at.isoformat(' '),
+            'updated_at': task.updated_at.isoformat(' ')
         }], result)
 
     @mock.patch('mistral.db.v2.api.get_task_execution')
@@ -257,7 +295,9 @@ class JinjaEvaluatorTest(base.BaseTest):
             'state': task_execution().state,
             'state_info': task_execution().state_info,
             'type': task_execution().type,
-            'workflow_execution_id': task_execution().workflow_execution_id
+            'workflow_execution_id': task_execution().workflow_execution_id,
+            'created_at': task_execution().created_at.isoformat(' '),
+            'updated_at': task_execution().updated_at.isoformat(' ')
         }, result)
 
     @mock.patch('mistral.db.v2.api.get_task_execution')
@@ -281,7 +321,9 @@ class JinjaEvaluatorTest(base.BaseTest):
             'state': task_execution().state,
             'state_info': task_execution().state_info,
             'type': task_execution().type,
-            'workflow_execution_id': task_execution().workflow_execution_id
+            'workflow_execution_id': task_execution().workflow_execution_id,
+            'created_at': task_execution().created_at.isoformat(' '),
+            'updated_at': task_execution().updated_at.isoformat(' ')
         }, result)
 
     @mock.patch('mistral.db.v2.api.get_workflow_execution')
@@ -301,9 +343,127 @@ class JinjaEvaluatorTest(base.BaseTest):
             'name': wf_ex.name,
             'spec': wf_ex.spec,
             'input': wf_ex.input,
-            'params': wf_ex.params
+            'params': wf_ex.params,
+            'created_at': wf_ex.created_at.isoformat(' '),
+            'updated_at': wf_ex.updated_at.isoformat(' ')
         }, result)
 
+    def test_executions(self):
+        with db_api.transaction(read_only=True):
+            created0 = db_api.create_workflow_execution(WF_EXECS[0])
+            created1 = db_api.create_workflow_execution(WF_EXECS[1])
+
+            ctx = {
+                '__execution': {
+                    'id': 'some'
+                }
+            }
+
+            result = self._evaluator.evaluate('_|executions()', ctx)
+
+            self.assertEqual([created0, created1], result)
+
+    def test_executions_id_filter(self):
+        with db_api.transaction(read_only=True):
+            created0 = db_api.create_workflow_execution(WF_EXECS[0])
+            created1 = db_api.create_workflow_execution(WF_EXECS[1])
+
+            ctx = {
+                '__execution': {
+                    'id': 'some'
+                }
+            }
+
+            result = self._evaluator.evaluate('_|executions("one")', ctx)
+
+            self.assertEqual([created0], result)
+
+            result = self._evaluator.evaluate(
+                'executions(root_execution_id="one") ', ctx
+            )
+            self.assertEqual([created1], result)
+
+    def test_executions_state_filter(self):
+        with db_api.transaction(read_only=True):
+            db_api.create_workflow_execution(WF_EXECS[0])
+            created1 = db_api.create_workflow_execution(WF_EXECS[1])
+
+            ctx = {
+                '__execution': {
+                    'id': 'some'
+                }
+            }
+
+            result = self._evaluator.evaluate(
+                '_|executions(state="RUNNING")', ctx
+            )
+
+            self.assertEqual([created1], result)
+
+            result = self._evaluator.evaluate(
+                '_|executions(id="one", state="RUNNING")', ctx
+            )
+
+            self.assertEqual([], result)
+
+    def test_executions_from_time_filter(self):
+        with db_api.transaction(read_only=True):
+            created0 = db_api.create_workflow_execution(WF_EXECS[0])
+            created1 = db_api.create_workflow_execution(WF_EXECS[1])
+
+            ctx = {
+                '__execution': {
+                    'id': 'some'
+                }
+            }
+
+            result = self._evaluator.evaluate(
+                '_|executions(from_time="2000-01-01")', ctx
+            )
+
+            self.assertEqual([created0, created1], result)
+
+            result = self._evaluator.evaluate(
+                '_|executions(from_time="2016-12-01 15:01:00")', ctx
+            )
+
+            self.assertEqual([created1], result)
+
+            result = self._evaluator.evaluate(
+                '_|executions(id="one", from_time="2016-12-01 15:01:00")', ctx
+            )
+
+            self.assertEqual([], result)
+
+    def test_executions_to_time_filter(self):
+        with db_api.transaction(read_only=True):
+            created0 = db_api.create_workflow_execution(WF_EXECS[0])
+            created1 = db_api.create_workflow_execution(WF_EXECS[1])
+
+            ctx = {
+                '__execution': {
+                    'id': 'some'
+                }
+            }
+
+            result = self._evaluator.evaluate(
+                '_|executions(to_time="2020-01-01")', ctx
+            )
+
+            self.assertEqual([created0, created1], result)
+
+            result = self._evaluator.evaluate(
+                '_|executions(to_time="2016-12-01 15:01:00")', ctx
+            )
+
+            self.assertEqual([created0], result)
+
+            result = self._evaluator.evaluate(
+                '_|executions(id="two", to_time="2016-12-01 15:01:00")', ctx
+            )
+
+            self.assertEqual([], result)
+
     @mock.patch('mistral.db.v2.api.get_workflow_execution')
     def test_function_execution(self, workflow_execution):
         wf_ex = mock.MagicMock(return_value={})
@@ -321,7 +481,9 @@ class JinjaEvaluatorTest(base.BaseTest):
             'name': wf_ex.name,
             'spec': wf_ex.spec,
             'input': wf_ex.input,
-            'params': wf_ex.params
+            'params': wf_ex.params,
+            'created_at': wf_ex.created_at.isoformat(' '),
+            'updated_at': wf_ex.updated_at.isoformat(' ')
         }, result)
 
 
@@ -402,6 +564,13 @@ class InlineJinjaEvaluatorTest(base.BaseTest):
         self.assertEqual(3, self._evaluator.evaluate('{{ _ }}', 3))
         self.assertEqual('33', self._evaluator.evaluate('{{ _ }}{{ _ }}', 3))
 
+    def test_multiple_expressions(self):
+        context = {'dir': '/tmp',
+                   'file': 'a.txt'}
+        expected_result = '/tmp/a.txt'
+        result = self._evaluator.evaluate('{{ _.dir }}/{{ _.file }}', context)
+        self.assertEqual(expected_result, result)
+
     def test_function_string(self):
         self.assertEqual('3', self._evaluator.evaluate('{{ _|string }}', '3'))
         self.assertEqual('3', self._evaluator.evaluate('{{ _|string }}', 3))
