@@ -14,11 +14,17 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+import datetime
+import json
+import sys
+import warnings
+
+import mock
+
 from mistral import exceptions as exc
 from mistral.expressions import yaql_expression as expr
 from mistral.tests.unit import base
 from mistral import utils
-import mock
 
 DATA = {
     "server": {
@@ -132,6 +138,38 @@ class YaqlEvaluatorTest(base.BaseTest):
             )
         )
 
+    def test_function_json_pp_deprecation(self):
+        with warnings.catch_warnings(record=True) as w:
+            # ensure warnings aren't suppressed from other tests
+            for name, mod in list(sys.modules.items()):
+                getattr(mod, '__warningregistry__', dict()).clear()
+            warnings.simplefilter('always')
+            result = self._evaluator.evaluate('json_pp($)', '3')
+            self.assertEqual('"3"', result)
+        self.assertEqual(len(w), 1)
+        self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
+        self.assertTrue(str(w[-1].message).startswith(
+            "json_pp was deprecated in Queens and will be removed in the S "
+        ))
+
+    def test_function_json_dump(self):
+        self.assertEqual('"3"', self._evaluator.evaluate('json_dump($)', '3'))
+        self.assertEqual('3', self._evaluator.evaluate('json_dump($)', 3))
+        self.assertEqual(
+            json.dumps([1, 2], indent=4),
+            self._evaluator.evaluate('json_dump($)', [1, 2])
+        )
+        self.assertEqual(
+            json.dumps({"a": "b"}, indent=4),
+            self._evaluator.evaluate('json_dump($)', {'a': 'b'})
+        )
+        self.assertEqual(
+            json.dumps('\n'.join(["Mistral", "is", "awesome"]), indent=4),
+            self._evaluator.evaluate(
+                'json_dump($)', '\n'.join(['Mistral', 'is', 'awesome'])
+            )
+        )
+
     def test_function_uuid(self):
         uuid = self._evaluator.evaluate('uuid()', {})
 
@@ -143,6 +181,7 @@ class YaqlEvaluatorTest(base.BaseTest):
                                                  task_executions):
 
         task_execution_result.return_value = 'task_execution_result'
+        time_now = utils.utc_now_sec()
         task = type("obj", (object,), {
             'id': 'id',
             'name': 'name',
@@ -152,7 +191,9 @@ class YaqlEvaluatorTest(base.BaseTest):
             'state': 'state',
             'state_info': 'state_info',
             'type': 'type',
-            'workflow_execution_id': 'workflow_execution_id'
+            'workflow_execution_id': 'workflow_execution_id',
+            'created_at': time_now,
+            'updated_at': time_now + datetime.timedelta(seconds=1),
         })()
 
         task_executions.return_value = [task]
@@ -176,7 +217,9 @@ class YaqlEvaluatorTest(base.BaseTest):
             'state': task.state,
             'state_info': task.state_info,
             'type': task.type,
-            'workflow_execution_id': task.workflow_execution_id
+            'workflow_execution_id': task.workflow_execution_id,
+            'created_at': task.created_at.isoformat(' '),
+            'updated_at': task.updated_at.isoformat(' ')
         }, result[0])
 
     def test_function_env(self):
