@@ -13,15 +13,13 @@
 #    limitations under the License.
 
 from oslo_config import cfg
-from oslo_log import log as logging
 
 from mistral.db.v2 import api as db_api
+from mistral.lang import parser as spec_parser
 from mistral.services import actions as action_service
-from mistral.tests import base
+from mistral.tests.unit import base
 from mistral import utils
-from mistral.workbook import parser as spec_parser
 
-LOG = logging.getLogger(__name__)
 
 # Use the set_default method to set value otherwise in certain test cases
 # the change in value is not permanent.
