@@ -1,4 +1,5 @@
 # Copyright 2016 Catalyst IT Ltd
+# Copyright 2017 Brocade Communications Systems, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,14 +13,16 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+import copy
 import time
 
 import mock
 from oslo_config import cfg
 
+from mistral import context as auth_context
 from mistral.db.v2.sqlalchemy import api as db_api
-from mistral.engine.rpc_backend import rpc
-from mistral.event_engine import event_engine
+from mistral.event_engine import default_event_engine as evt_eng
+from mistral.rpc import clients as rpc
 from mistral.services import workflows
 from mistral.tests.unit import base
 
@@ -61,7 +64,7 @@ class EventEngineTest(base.DbTestCase):
 
     @mock.patch.object(rpc, 'get_engine_client', mock.Mock())
     def test_event_engine_start_with_no_triggers(self):
-        e_engine = event_engine.EventEngine()
+        e_engine = evt_eng.DefaultEventEngine()
 
         self.addCleanup(e_engine.handler_tg.stop)
 
@@ -74,7 +77,7 @@ class EventEngineTest(base.DbTestCase):
     def test_event_engine_start_with_triggers(self, mock_start):
         trigger = db_api.create_event_trigger(EVENT_TRIGGER)
 
-        e_engine = event_engine.EventEngine()
+        e_engine = evt_eng.DefaultEventEngine()
 
         self.addCleanup(e_engine.handler_tg.stop)
 
@@ -93,10 +96,22 @@ class EventEngineTest(base.DbTestCase):
 
     @mock.patch('mistral.messaging.start_listener')
     @mock.patch.object(rpc, 'get_engine_client', mock.Mock())
-    def test_process_event_queue(self, mock_start):
-        db_api.create_event_trigger(EVENT_TRIGGER)
+    def test_event_engine_public_trigger(self, mock_start):
+        t = copy.deepcopy(EVENT_TRIGGER)
 
-        e_engine = event_engine.EventEngine()
+        # Create public trigger as an admin
+        self.ctx = base.get_context(default=False, admin=True)
+        auth_context.set_ctx(self.ctx)
+
+        t['scope'] = 'public'
+        t['project_id'] = self.ctx.tenant
+        trigger = db_api.create_event_trigger(t)
+
+        # Switch to the user.
+        self.ctx = base.get_context(default=True)
+        auth_context.set_ctx(self.ctx)
+
+        e_engine = evt_eng.DefaultEventEngine()
 
         self.addCleanup(e_engine.handler_tg.stop)
 
@@ -105,7 +120,56 @@ class EventEngineTest(base.DbTestCase):
             'payload': {},
             'publisher': 'fake_publisher',
             'timestamp': '',
-            'context': {'project_id': 'fake_project', 'user_id': 'fake_user'},
+            'context': {
+                'project_id': '%s' % self.ctx.project_id,
+                'user_id': 'fake_user'
+            },
+        }
+
+        # Moreover, assert that trigger.project_id != event.project_id
+        self.assertNotEqual(
+            trigger.project_id, event['context']['project_id']
+        )
+
+        with mock.patch.object(e_engine, 'engine_client') as client_mock:
+            e_engine.event_queue.put(event)
+
+            time.sleep(1)
+
+            self.assertEqual(1, client_mock.start_workflow.call_count)
+
+            args, kwargs = client_mock.start_workflow.call_args
+
+            self.assertEqual((EVENT_TRIGGER['workflow_id'], '', {}), args)
+            self.assertDictEqual(
+                {
+                    'service': 'fake_publisher',
+                    'project_id': '%s' % self.ctx.project_id,
+                    'user_id': 'fake_user',
+                    'timestamp': ''
+                },
+                kwargs['event_params']
+            )
+
+    @mock.patch('mistral.messaging.start_listener')
+    @mock.patch.object(rpc, 'get_engine_client', mock.Mock())
+    def test_process_event_queue(self, mock_start):
+        EVENT_TRIGGER['project_id'] = self.ctx.project_id
+        db_api.create_event_trigger(EVENT_TRIGGER)
+
+        e_engine = evt_eng.DefaultEventEngine()
+
+        self.addCleanup(e_engine.handler_tg.stop)
+
+        event = {
+            'event_type': EVENT_TYPE,
+            'payload': {},
+            'publisher': 'fake_publisher',
+            'timestamp': '',
+            'context': {
+                'project_id': '%s' % self.ctx.project_id,
+                'user_id': 'fake_user'
+            },
         }
 
         with mock.patch.object(e_engine, 'engine_client') as client_mock:
@@ -117,11 +181,11 @@ class EventEngineTest(base.DbTestCase):
 
             args, kwargs = client_mock.start_workflow.call_args
 
-            self.assertEqual((EVENT_TRIGGER['workflow_id'], {}), args)
+            self.assertEqual((EVENT_TRIGGER['workflow_id'], '', {}), args)
             self.assertDictEqual(
                 {
                     'service': 'fake_publisher',
-                    'project_id': 'fake_project',
+                    'project_id': '%s' % self.ctx.project_id,
                     'user_id': 'fake_user',
                     'timestamp': ''
                 },
@@ -138,8 +202,8 @@ class NotificationsConverterTest(base.BaseTest):
             }
         ]
 
-        converter = event_engine.NotificationsConverter()
-        converter.definitions = [event_engine.EventDefinition(event_def)
+        converter = evt_eng.NotificationsConverter()
+        converter.definitions = [evt_eng.EventDefinition(event_def)
                                  for event_def in reversed(definition_cfg)]
 
         notification = {
@@ -165,8 +229,8 @@ class NotificationsConverterTest(base.BaseTest):
             }
         ]
 
-        converter = event_engine.NotificationsConverter()
-        converter.definitions = [event_engine.EventDefinition(event_def)
+        converter = evt_eng.NotificationsConverter()
+        converter.definitions = [evt_eng.EventDefinition(event_def)
                                  for event_def in reversed(definition_cfg)]
 
         notification = {
