@@ -12,15 +12,13 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 from mistral.db.v2 import api as db_api
-from mistral.openstack.common import log as logging
+from mistral.lang import parser as spec_parser
 from mistral.services import workbooks as wb_service
-from mistral.tests.unit.engine1 import base
-from mistral.workbook import parser as spec_parser
+from mistral.tests.unit import base
 
-LOG = logging.getLogger(__name__)
 
 # Use the set_default method to set value otherwise in certain test cases
 # the change in value is not permanent.
@@ -42,22 +40,24 @@ actions:
 
 workflows:
   wf1:
+#Sample Comment 1
     type: reverse
+    tags: [wf_test]
     input:
       - param1
     output:
-      result: $.result
+      result: "{$.result}"
 
     tasks:
       task1:
         action: std.echo output="{$.param1}"
         publish:
-          result: $
+          result: "{$}"
 
   wf2:
     type: direct
     output:
-      result: $.result
+      result: "{$.result}"
 
     tasks:
       task1:
@@ -66,6 +66,35 @@ workflows:
           result: "The result of subworkflow is '{$.final_result}'"
 """
 
+WORKBOOK_WF1_DEFINITION = """wf1:
+#Sample Comment 1
+  type: reverse
+  tags: [wf_test]
+  input:
+    - param1
+  output:
+    result: "{$.result}"
+
+  tasks:
+    task1:
+      action: std.echo output="{$.param1}"
+      publish:
+        result: "{$}"
+"""
+
+WORKBOOK_WF2_DEFINITION = """wf2:
+  type: direct
+  output:
+    result: "{$.result}"
+
+  tasks:
+    task1:
+      workflow: my_wb.wf1 param1='Hi' task_name='task1'
+      publish:
+        result: "The result of subworkflow is '{$.final_result}'"
+"""
+
+
 UPDATED_WORKBOOK = """
 ---
 version: '2.0'
@@ -83,7 +112,7 @@ workflows:
   wf1:
     type: direct
     output:
-      result: $.result
+      result: "{$.result}"
 
     tasks:
       task1:
@@ -96,19 +125,52 @@ workflows:
     input:
       - param1
     output:
-      result: $.result
+      result: "{$.result}"
 
     tasks:
       task1:
         action: std.echo output="{$.param1}"
         publish:
-          result: $
+          result: "{$}"
+"""
+
+UPDATED_WORKBOOK_WF1_DEFINITION = """wf1:
+  type: direct
+  output:
+    result: "{$.result}"
+
+  tasks:
+    task1:
+      workflow: my_wb.wf2 param1='Hi' task_name='task1'
+      publish:
+        result: "The result of subworkflow is '{$.final_result}'"
+"""
+
+UPDATED_WORKBOOK_WF2_DEFINITION = """wf2:
+  type: reverse
+  input:
+    - param1
+  output:
+    result: "{$.result}"
+
+  tasks:
+    task1:
+      action: std.echo output="{$.param1}"
+      publish:
+        result: "{$}"
 """
 
 
-class WorkbookServiceTest(base.EngineTestCase):
+ACTION_DEFINITION = """concat:
+  base: std.echo
+  base-input:
+    output: "{$.str1}{$.str2}"
+"""
+
+
+class WorkbookServiceTest(base.DbTestCase):
     def test_create_workbook(self):
-        wb_db = wb_service.create_workbook_v2({'definition': WORKBOOK})
+        wb_db = wb_service.create_workbook_v2(WORKBOOK)
 
         self.assertIsNotNone(wb_db)
         self.assertEqual('my_wb', wb_db.name)
@@ -116,7 +178,7 @@ class WorkbookServiceTest(base.EngineTestCase):
         self.assertIsNotNone(wb_db.spec)
         self.assertListEqual(['test'], wb_db.tags)
 
-        db_actions = db_api.get_actions(name='my_wb.concat')
+        db_actions = db_api.get_action_definitions(name='my_wb.concat')
 
         self.assertEqual(1, len(db_actions))
 
@@ -129,8 +191,9 @@ class WorkbookServiceTest(base.EngineTestCase):
 
         self.assertEqual('concat', action_spec.get_name())
         self.assertEqual('std.echo', action_spec.get_base())
+        self.assertEqual(ACTION_DEFINITION, action_db.definition)
 
-        db_wfs = db_api.get_workflows()
+        db_wfs = db_api.get_workflow_definitions()
 
         self.assertEqual(2, len(db_wfs))
 
@@ -140,6 +203,9 @@ class WorkbookServiceTest(base.EngineTestCase):
 
         self.assertEqual('wf1', wf1_spec.get_name())
         self.assertEqual('reverse', wf1_spec.get_type())
+        self.assertListEqual(['wf_test'], wf1_spec.get_tags())
+        self.assertListEqual(['wf_test'], wf1_db.tags)
+        self.assertEqual(WORKBOOK_WF1_DEFINITION, wf1_db.definition)
 
         # Workflow 2.
         wf2_db = self._assert_single_item(db_wfs, name='my_wb.wf2')
@@ -147,25 +213,24 @@ class WorkbookServiceTest(base.EngineTestCase):
 
         self.assertEqual('wf2', wf2_spec.get_name())
         self.assertEqual('direct', wf2_spec.get_type())
+        self.assertEqual(WORKBOOK_WF2_DEFINITION, wf2_db.definition)
 
     def test_update_workbook(self):
         # Create workbook.
-        wb_db = wb_service.create_workbook_v2({'definition': WORKBOOK})
+        wb_db = wb_service.create_workbook_v2(WORKBOOK)
 
         self.assertIsNotNone(wb_db)
-        self.assertEqual(2, len(db_api.get_workflows()))
+        self.assertEqual(2, len(db_api.get_workflow_definitions()))
 
         # Update workbook.
-        wb_db = wb_service.update_workbook_v2(
-            {'definition': UPDATED_WORKBOOK}
-        )
+        wb_db = wb_service.update_workbook_v2(UPDATED_WORKBOOK)
 
         self.assertIsNotNone(wb_db)
         self.assertEqual('my_wb', wb_db.name)
         self.assertEqual(UPDATED_WORKBOOK, wb_db.definition)
         self.assertListEqual(['test'], wb_db.tags)
 
-        db_wfs = db_api.get_workflows()
+        db_wfs = db_api.get_workflow_definitions()
 
         self.assertEqual(2, len(db_wfs))
 
@@ -175,6 +240,7 @@ class WorkbookServiceTest(base.EngineTestCase):
 
         self.assertEqual('wf1', wf1_spec.get_name())
         self.assertEqual('direct', wf1_spec.get_type())
+        self.assertEqual(UPDATED_WORKBOOK_WF1_DEFINITION, wf1_db.definition)
 
         # Workflow 2.
         wf2_db = self._assert_single_item(db_wfs, name='my_wb.wf2')
@@ -182,3 +248,4 @@ class WorkbookServiceTest(base.EngineTestCase):
 
         self.assertEqual('wf2', wf2_spec.get_name())
         self.assertEqual('reverse', wf2_spec.get_type())
+        self.assertEqual(UPDATED_WORKBOOK_WF2_DEFINITION, wf2_db.definition)
