@@ -17,7 +17,7 @@
 import copy
 
 from mistral import exceptions as exc
-from mistral.tests import base
+from mistral.tests.unit import base
 from mistral import utils
 from mistral.utils import ssh_utils
 
@@ -42,9 +42,6 @@ RIGHT = {
 
 
 class UtilsTest(base.BaseTest):
-    def setUp(self):
-        super(UtilsTest, self).setUp()
-
     def test_merge_dicts(self):
         left = copy.deepcopy(LEFT)
         right = copy.deepcopy(RIGHT)
@@ -100,25 +97,26 @@ class UtilsTest(base.BaseTest):
 
         self.assertEqual([B, C, D], list(utils.iter_subclasses(A)))
 
-    def test_get_input_dict(self):
+    def test_get_dict_from_entries(self):
         input = ['param1', {'param2': 2}]
-        input_dict = utils.get_input_dict(input)
+        input_dict = utils.get_dict_from_entries(input)
 
         self.assertIn('param1', input_dict)
         self.assertIn('param2', input_dict)
         self.assertEqual(2, input_dict.get('param2'))
         self.assertIs(input_dict.get('param1'), utils.NotDefined)
 
-    def test_get_input_dict_from_input_string(self):
-        input_string = 'param1, param2=2, param3="var3"'
-        input_dict = utils.get_dict_from_string(input_string)
+    def test_get_input_dict_from_string(self):
+        self.assertDictEqual(
+            {
+                'param1': utils.NotDefined,
+                'param2': 2,
+                'param3': 'var3'
+            },
+            utils.get_dict_from_string('param1, param2=2, param3="var3"')
+        )
 
-        self.assertIn('param1', input_dict)
-        self.assertIn('param2', input_dict)
-        self.assertIn('param3', input_dict)
-        self.assertEqual(2, input_dict.get('param2'))
-        self.assertEqual('var3', input_dict.get('param3'))
-        self.assertIs(input_dict.get('param1'), utils.NotDefined)
+        self.assertDictEqual({}, utils.get_dict_from_string(''))
 
     def test_paramiko_to_private_key(self):
         self.assertRaises(
@@ -131,3 +129,68 @@ class UtilsTest(base.BaseTest):
             ssh_utils._to_paramiko_private_key,
             "..\\dir"
         )
+
+    def test_cut_string(self):
+        s = 'Hello, Mistral!'
+
+        self.assertEqual('Hello...', utils.cut_string(s, length=5))
+        self.assertEqual(s, utils.cut_string(s, length=100))
+
+    def test_cut_list(self):
+        l = ['Hello, Mistral!', 'Hello, OpenStack!']
+
+        self.assertEqual("['Hello, M...", utils.cut_list(l, 11))
+        self.assertEqual("['Hello, Mistr...", utils.cut_list(l, 15))
+        self.assertEqual("['Hello, Mistral!', 'He...", utils.cut_list(l, 24))
+
+        self.assertEqual(
+            "['Hello, Mistral!', 'Hello, OpenStack!']",
+            utils.cut_list(l, 100)
+        )
+
+        self.assertEqual("[1, 2...", utils.cut_list([1, 2, 3, 4, 5], 4))
+        self.assertEqual("[1, 2...", utils.cut_list([1, 2, 3, 4, 5], 5))
+        self.assertEqual("[1, 2, 3...", utils.cut_list([1, 2, 3, 4, 5], 6))
+
+        self.assertRaises(ValueError, utils.cut_list, (1, 2))
+
+    def test_cut_dict_with_strings(self):
+        d = {'key1': 'value1', 'key2': 'value2'}
+
+        s = utils.cut_dict(d, 9)
+
+        self.assertIn(s, ["{'key1': '...", "{'key2': '..."])
+
+        s = utils.cut_dict(d, 13)
+
+        self.assertIn(s, ["{'key1': 'va...", "{'key2': 'va..."])
+
+        s = utils.cut_dict(d, 19)
+
+        self.assertIn(
+            s,
+            ["{'key1': 'value1', ...", "{'key2': 'value2', ..."]
+        )
+
+        self.assertIn(
+            utils.cut_dict(d, 100),
+            [
+                "{'key1': 'value1', 'key2': 'value2'}",
+                "{'key2': 'value2', 'key1': 'value1'}"
+            ]
+        )
+
+    def test_cut_dict_with_digits(self):
+        d = {1: 2, 3: 4}
+
+        s = utils.cut_dict(d, 6)
+
+        self.assertIn(s, ["{1: 2, ...", "{3: 4, ..."])
+
+        s = utils.cut_dict(d, 8)
+
+        self.assertIn(s, ["{1: 2, 3...", "{3: 4, 1..."])
+
+        s = utils.cut_dict(d, 100)
+
+        self.assertIn(s, ["{1: 2, 3: 4}", "{3: 4, 1: 2}"])
