@@ -18,7 +18,6 @@ import contextlib
 import datetime
 import functools
 import json
-import logging
 import os
 from os import path
 import shutil
@@ -30,6 +29,7 @@ import threading
 import eventlet
 from eventlet import corolocal
 from oslo_concurrency import processutils
+from oslo_log import log as logging
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import pkg_resources as pkg
@@ -311,9 +311,11 @@ def cut_by_kb(data, kilobytes):
     if kilobytes <= 0:
         return cut(data)
 
-    bytes_per_char = sys.getsizeof('s') - sys.getsizeof('')
-    length = int(kilobytes * 1024 / bytes_per_char)
+    length = get_number_of_chars_from_kilobytes(kilobytes)
+    return cut(data, length)
 
+
+def cut_by_char(data, length):
     return cut(data, length)
 
 
@@ -365,6 +367,12 @@ class NotDefined(object):
     pass
 
 
+def get_number_of_chars_from_kilobytes(kilobytes):
+    bytes_per_char = sys.getsizeof('s') - sys.getsizeof('')
+    total_number_of_chars = int(kilobytes * 1024 / bytes_per_char)
+    return total_number_of_chars
+
+
 def get_dict_from_string(string, delimiter=','):
     if not string:
         return {}
