@@ -13,6 +13,7 @@
 #    limitations under the License.
 
 import inspect
+import json
 
 
 def get_public_fields(obj):
@@ -22,11 +23,13 @@ def get_public_fields(obj):
                          if not attr.startswith("_")]
 
     public_fields = {}
+
     for attribute_str in public_attributes:
         attr = getattr(obj, attribute_str)
         is_field = not (inspect.isbuiltin(attr)
                         or inspect.isfunction(attr)
-                        or inspect.ismethod(attr))
+                        or inspect.ismethod(attr)
+                        or isinstance(attr, property))
 
         if is_field:
             public_fields[attribute_str] = attr
@@ -38,22 +41,45 @@ def get_docstring(obj):
     return inspect.getdoc(obj)
 
 
+def get_arg_list(func):
+    argspec = inspect.getargspec(func)
+
+    args = argspec.args
+
+    if 'self' in args:
+        args.remove('self')
+
+    return args
+
+
 def get_arg_list_as_str(func):
+    args = getattr(func, "__arguments__", None)
+    if args:
+        return args
+
     argspec = inspect.getargspec(func)
     defs = list(argspec.defaults or [])
 
-    args = argspec.args
-    if 'self' in args:
-        args.remove('self')
+    args = get_arg_list(func)
 
     diff_args_defs = len(args) - len(defs)
     arg_str_list = []
 
     for index, default in enumerate(args):
         if index >= diff_args_defs:
-            arg_str_list.append("%s=%s" % (args[index],
-                                           defs[index - diff_args_defs]))
+            try:
+                arg_str_list.append(
+                    "%s=%s" % (
+                        args[index],
+                        json.dumps(defs[index - diff_args_defs])
+                    )
+                )
+            except TypeError:
+                pass
         else:
             arg_str_list.append("%s" % args[index])
 
+    if argspec.keywords:
+        arg_str_list.append("**%s" % argspec.keywords)
+
     return ", ".join(arg_str_list)
