@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2013 - Mirantis, Inc.
+# Copyright 2016 - Brocade Communications Systems, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -17,21 +16,34 @@
 """Valid task and workflow states."""
 
 IDLE = 'IDLE'
+WAITING = 'WAITING'
 RUNNING = 'RUNNING'
+RUNNING_DELAYED = 'DELAYED'
 PAUSED = 'PAUSED'
-DELAYED = 'DELAYED'
 SUCCESS = 'SUCCESS'
+CANCELLED = 'CANCELLED'
 ERROR = 'ERROR'
 
-_ALL = [IDLE, RUNNING, SUCCESS, ERROR, PAUSED, DELAYED]
+_ALL = [
+    IDLE,
+    WAITING,
+    RUNNING,
+    RUNNING_DELAYED,
+    PAUSED,
+    SUCCESS,
+    CANCELLED,
+    ERROR
+]
 
 _VALID_TRANSITIONS = {
-    IDLE: [RUNNING, ERROR],
-    RUNNING: [PAUSED, DELAYED, SUCCESS, ERROR],
-    PAUSED: [RUNNING, ERROR],
-    DELAYED: [RUNNING, ERROR],
+    IDLE: [RUNNING, ERROR, CANCELLED],
+    WAITING: [RUNNING],
+    RUNNING: [PAUSED, RUNNING_DELAYED, SUCCESS, ERROR, CANCELLED],
+    RUNNING_DELAYED: [RUNNING, ERROR, CANCELLED],
+    PAUSED: [RUNNING, ERROR, CANCELLED],
     SUCCESS: [],
-    ERROR: []
+    CANCELLED: [RUNNING],
+    ERROR: [RUNNING]
 }
 
 
@@ -43,12 +55,36 @@ def is_invalid(state):
     return not is_valid(state)
 
 
-def is_finished(state):
-    return state in [SUCCESS, ERROR]
+def is_completed(state):
+    return state in [SUCCESS, ERROR, CANCELLED]
 
 
-def is_paused_or_finished(state):
-    return state == PAUSED or is_finished(state)
+def is_cancelled(state):
+    return state == CANCELLED
+
+
+def is_running(state):
+    return state in [RUNNING, RUNNING_DELAYED]
+
+
+def is_waiting(state):
+    return state == WAITING
+
+
+def is_idle(state):
+    return state == IDLE
+
+
+def is_paused(state):
+    return state == PAUSED
+
+
+def is_paused_or_completed(state):
+    return is_paused(state) or is_completed(state)
+
+
+def is_paused_or_idle(state):
+    return is_paused(state) or is_idle(state)
 
 
 def is_valid_transition(from_state, to_state):
